@@ -31,7 +31,7 @@ void cd_animations_draw_unfolding_icon_cairo (Icon *pIcon, CairoDock *pDock, CDA
 	int w, h;
 	cairo_dock_get_icon_extent (pIcon, &w, &h);
 	double f = 1. - pIcon->pSubDock->fFoldingFactor;
-	double fMaxScale = cairo_dock_get_max_scale (CAIRO_CONTAINER (pDock));
+	double fMaxScale = (pIcon->fHeight != 0 ? (pDock->container.bIsHorizontal ? pIcon->iImageHeight : pIcon->iImageWidth) / pIcon->fHeight : 1.);
 	double z = pIcon->fScale / fMaxScale * pDock->container.fRatio;
 	
 	//\______________ On dessine la boite derriere.
@@ -55,11 +55,6 @@ void cd_animations_draw_unfolding_icon_cairo (Icon *pIcon, CairoDock *pDock, CDA
 	cairo_scale(pCairoContext,
 		(double) w / g_pBoxBelowBuffer.iWidth,
 		(double) h / g_pBoxBelowBuffer.iHeight);
-	/**cairo_set_source_surface (pCairoContext,
-		g_pBoxBelowBuffer.pSurface,
-		0.,
-		0.);
-	cairo_paint (pCairoContext);*/
 	cairo_dock_draw_surface (pCairoContext,
 		g_pBoxBelowBuffer.pSurface,
 		g_pBoxBelowBuffer.iWidth, g_pBoxBelowBuffer.iHeight,
@@ -80,11 +75,9 @@ void cd_animations_draw_unfolding_icon_cairo (Icon *pIcon, CairoDock *pDock, CDA
 		if (! pDock->container.bDirectionUp)
 			cairo_translate (pCairoContext, .2*h, 0.);
 	}
-	cairo_scale(pCairoContext,
-		.8,
-		.8);
 	int i;
 	double dx, dy;
+	int wi, hi;
 	Icon *icon;
 	GList *ic;
 	for (ic = pIcon->pSubDock->icons, i = 0; ic != NULL && i < 3; ic = ic->next, i++)
@@ -112,11 +105,18 @@ void cd_animations_draw_unfolding_icon_cairo (Icon *pIcon, CairoDock *pDock, CDA
 			else
 				dx = - (.1*i - f*1.5) * h/z;
 		}
+		
+		cairo_dock_get_icon_extent (icon, &wi, &hi);
+		
+		cairo_save (pCairoContext);
+		cairo_translate (pCairoContext, dx, dy);
+		cairo_scale (pCairoContext, .8 * w / wi, .8 * h / hi);
 		cairo_set_source_surface (pCairoContext,
 			icon->pIconBuffer,
-			dx,
-			dy);
+			0,
+			0);
 		cairo_paint_with_alpha (pCairoContext, 1. - f);
+		cairo_restore (pCairoContext);
 	}
 	cairo_restore (pCairoContext);
 	
@@ -125,11 +125,6 @@ void cd_animations_draw_unfolding_icon_cairo (Icon *pIcon, CairoDock *pDock, CDA
 	cairo_scale(pCairoContext,
 		(double) w / g_pBoxAboveBuffer.iWidth,
 		(double) h / g_pBoxAboveBuffer.iHeight);
-	/**cairo_set_source_surface (pCairoContext,
-		g_pBoxAboveBuffer.pSurface,
-		0.,
-		0.);
-	cairo_paint (pCairoContext);*/
 	cairo_dock_draw_surface (pCairoContext,
 		g_pBoxAboveBuffer.pSurface,
 		g_pBoxAboveBuffer.iWidth, g_pBoxAboveBuffer.iHeight,
@@ -139,9 +134,9 @@ void cd_animations_draw_unfolding_icon_cairo (Icon *pIcon, CairoDock *pDock, CDA
 	cairo_restore (pCairoContext);
 	
 	//\_____________________ On dessine son reflet.
-	cairo_dock_draw_icon_reflect_cairo (pIcon, pDock, pCairoContext);
+	cairo_restore (pCairoContext);  // come back to the original context
 	
-	cairo_restore (pCairoContext);
+	cairo_dock_draw_icon_reflect_cairo (pIcon, CAIRO_CONTAINER (pDock), pCairoContext);
 }
 
 
@@ -151,7 +146,7 @@ void cd_animations_draw_unfolding_icon (Icon *pIcon, CairoDock *pDock, CDAnimati
 	int w, h;
 	cairo_dock_get_icon_extent (pIcon, &w, &h);
 	double f = 1. - pIcon->pSubDock->fFoldingFactor;
-	double fMaxScale = cairo_dock_get_max_scale (CAIRO_CONTAINER (pDock));
+	double fMaxScale = (pIcon->fHeight != 0 ? (pDock->container.bIsHorizontal ? pIcon->iImageHeight : pIcon->iImageWidth) / pIcon->fHeight : 1.);
 	double z = pIcon->fScale / fMaxScale * pDock->container.fRatio;
 	
 	//\______________ On dessine la boite derriere.
@@ -195,7 +190,6 @@ void cd_animations_draw_unfolding_icon (Icon *pIcon, CairoDock *pDock, CDAnimati
 	glMatrixMode (GL_MODELVIEW);
 	_cairo_dock_set_alpha (sqrt (MAX (0., 1. - f)));  // on reduit un peu la transparence en opengl.
 	int i;
-	double dx = 0., dy = 0.;
 	Icon *icon;
 	GList *ic;
 	for (ic = pIcon->pSubDock->icons, i = 0; ic != NULL && i < 3; ic = ic->next, i++)
