@@ -102,6 +102,7 @@ static gboolean _applet_set_icon (dbusApplet *pDbusApplet, const gchar *cImage,
 	return TRUE;
 }
 
+/* Not used
 static gboolean _applet_set_icon_with_default (dbusApplet *pDbusApplet, const gchar **cImages, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
@@ -121,7 +122,7 @@ static gboolean _applet_set_icon_with_default (dbusApplet *pDbusApplet, const gc
 	cairo_dock_redraw_icon (pIcon, pContainer);
 	return TRUE;
 }
-
+*/
 static gboolean _applet_set_emblem (dbusApplet *pDbusApplet, const gchar *cImage, gint iPosition, const gchar *cIconID, GError **error)
 {
 	Icon *pIcon;
@@ -129,20 +130,17 @@ static gboolean _applet_set_emblem (dbusApplet *pDbusApplet, const gchar *cImage
 	if (! _get_icon_and_container_from_id (pDbusApplet, cIconID, &pIcon, &pContainer))
 		return FALSE;
 	
-	g_return_val_if_fail (pIcon->pIconBuffer != NULL, FALSE);
-	
 	if (cImage == NULL || *cImage == '\0' || strcmp (cImage, "none") == 0)
 	{
-		cairo_dock_remove_overlay_at_position (pIcon, iPosition);
+		cairo_dock_remove_overlay_at_position (pIcon, iPosition < CAIRO_OVERLAY_NB_POSITIONS ? iPosition : iPosition - CAIRO_OVERLAY_NB_POSITIONS, myApplet);  // for ease of use, handle both case similarily.
 	}
 	else
 	{
-		cairo_dock_add_overlay_from_image (pIcon, cImage, iPosition);
+		if (iPosition >= CAIRO_OVERLAY_NB_POSITIONS)  // [N; 2N-1] => print the overlay
+			cairo_dock_print_overlay_on_icon_from_image (pIcon, pContainer, cImage, iPosition - CAIRO_OVERLAY_NB_POSITIONS);
+		else  // [0, N-1] => add it
+			cairo_dock_add_overlay_from_image (pIcon, cImage, iPosition, myApplet);  // use 'myApplet' to identify the overlays set by the Dbus plug-in (since the plug-in can't be deactivated, 'myApplet' is constant).
 	}
-	/**CairoEmblem *pEmblem = cairo_dock_make_emblem (cImage, pIcon);
-	pEmblem->iPosition = iPosition;
-	cairo_dock_draw_emblem_on_icon (pEmblem, pIcon, pContainer);
-	cairo_dock_free_emblem (pEmblem);*/
 	
 	cairo_dock_redraw_icon (pIcon, pContainer);
 	return TRUE;
@@ -295,10 +293,9 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 	if (v && G_VALUE_HOLDS_BOOLEAN (v))
 		attr.bForceAbove = g_value_get_boolean (v);
 	
-	gboolean bUseMarkup = FALSE;
 	v = g_hash_table_lookup (hDialogAttributes, "use-markup");
 	if (v && G_VALUE_HOLDS_BOOLEAN (v))
-		bUseMarkup = g_value_get_boolean (v);
+		attr.bUseMarkup = g_value_get_boolean (v);
 	
 	attr.pUserData = pDbusApplet;
 	attr.pFreeDataFunc = (GFreeFunc)_on_dialog_destroyed;
@@ -557,13 +554,9 @@ static gboolean _applet_popup_dialog (dbusApplet *pDbusApplet, GHashTable *hDial
 	else
 		g_object_set_data (G_OBJECT (pInteractiveWidget), "cd-widget", pOneWidget);
 	
-	if (bUseMarkup)
-		myDialogsParam.dialogTextDescription.bUseMarkup = TRUE;
 	pDbusApplet->pDialog = cairo_dock_build_dialog (&attr, pIcon, pContainer);
 	if (pOneWidget)
 		gtk_widget_grab_focus (pOneWidget);
-	if (bUseMarkup)
-		myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;
 	
 	g_free (cImageFilePath);
 	if (cButtonsImage)
@@ -746,26 +739,26 @@ gboolean cd_dbus_applet_demands_attention (dbusApplet *pDbusApplet, gboolean bSt
 
 gboolean cd_dbus_applet_show_dialog (dbusApplet *pDbusApplet, const gchar *message, gint iDuration, GError **error)
 {
-	cd_debug ("%s (%s)\n", __func__, message);
+	cd_debug ("%s (%s)", __func__, message);
 	return _applet_show_dialog (pDbusApplet, message, iDuration, NULL, error);
 }
 
 // deprecated
 gboolean cd_dbus_applet_ask_question (dbusApplet *pDbusApplet, const gchar *message, GError **error)
 {
-	cd_debug ("%s (%s)\n", __func__, message);
+	cd_debug ("%s (%s)", __func__, message);
 	return _applet_ask_question (pDbusApplet, message, NULL, error);
 }
 
 gboolean cd_dbus_applet_ask_value (dbusApplet *pDbusApplet, const gchar *message, gdouble fInitialValue, gdouble fMaxValue, GError **error)
 {
-	cd_debug ("%s (%s)\n", __func__, message);
+	cd_debug ("%s (%s)", __func__, message);
 	return _applet_ask_value (pDbusApplet, message, fInitialValue, fMaxValue, NULL, error);
 }
 
 gboolean cd_dbus_applet_ask_text (dbusApplet *pDbusApplet, const gchar *message, const gchar *cInitialText, GError **error)
 {
-	cd_debug ("%s (%s)\n", __func__, message);
+	cd_debug ("%s (%s)", __func__, message);
 	return _applet_ask_text (pDbusApplet, message, cInitialText, NULL, error);
 }
 // end of deprecated
@@ -787,37 +780,35 @@ gboolean cd_dbus_applet_add_data_renderer (dbusApplet *pDbusApplet, const gchar
 	CairoContainer *pContainer = pInstance->pContainer;
 	g_return_val_if_fail (pContainer != NULL, FALSE);
 	
-	CairoDataRendererAttribute *pRenderAttr = NULL;  // les attributs du data-renderer global.
+	CairoDataRendererAttribute *pRenderAttr = NULL;  // attributes for the global data-renderer.
+	CairoGaugeAttribute aGaugeAttr;  // gauge attributes.
+	CairoGraphAttribute aGraphAttr;  // graph attributes.
+	CairoGraphAttribute aProgressBarAttr;  // progressbar attributes.
 	if (strcmp (cType, "gauge") == 0)
 	{
-		CairoGaugeAttribute attr;  // les attributs de la jauge.
-		memset (&attr, 0, sizeof (CairoGaugeAttribute));
-		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
-		pRenderAttr->cModelName = "gauge";
-		///attr.cThemePath = cairo_dock_get_gauge_theme_path (cTheme, CAIRO_DOCK_ANY_THEME);
-		attr.cThemePath = cairo_dock_get_data_renderer_theme_path ("gauge", cTheme, CAIRO_DOCK_ANY_PACKAGE);
+		memset (&aGaugeAttr, 0, sizeof (CairoGaugeAttribute));
+		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&aGaugeAttr);
+		aGaugeAttr.cThemePath = cairo_dock_get_data_renderer_theme_path (cType, cTheme, CAIRO_DOCK_ANY_PACKAGE);
 	}
-	else if (strcmp (cType, "gauge") == 0)
+	else if (strcmp (cType, "graph") == 0)
 	{
-		CairoGraphAttribute attr;  // les attributs du graphe.
-		memset (&attr, 0, sizeof (CairoGraphAttribute));
-		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
-		pRenderAttr->cModelName = "graph";
+		memset (&aGraphAttr, 0, sizeof (CairoGraphAttribute));
+		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&aGraphAttr);
 		int w, h;
 		cairo_dock_get_icon_extent (pIcon, &w, &h);
 		pRenderAttr->iMemorySize = (w > 1 ? w : 32);
 		// Line;Plain;Bar;Circle;Plain Circle
 		if (cTheme == NULL || strcmp (cTheme, "Line") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH_LINE;
+			aGraphAttr.iType = CAIRO_DOCK_GRAPH_LINE;
 		else if (strcmp (cTheme, "Plain") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH_PLAIN;
+			aGraphAttr.iType = CAIRO_DOCK_GRAPH_PLAIN;
 		else if (strcmp (cTheme, "Bar") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH_BAR;
+			aGraphAttr.iType = CAIRO_DOCK_GRAPH_BAR;
 		else if (strcmp (cTheme, "Circle") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH_CIRCLE;
+			aGraphAttr.iType = CAIRO_DOCK_GRAPH_CIRCLE;
 		else if (strcmp (cTheme, "Plain Circle") == 0)
-			attr.iType = CAIRO_DOCK_GRAPH_CIRCLE_PLAIN;
-		attr.bMixGraphs = FALSE;
+			aGraphAttr.iType = CAIRO_DOCK_GRAPH_CIRCLE_PLAIN;
+		aGraphAttr.bMixGraphs = FALSE;
 		double *fHighColor = g_new (double, iNbValues*3);
 		double *fLowColor = g_new (double, iNbValues*3);
 		int i;
@@ -830,31 +821,33 @@ gboolean cd_dbus_applet_add_data_renderer (dbusApplet *pDbusApplet, const gchar
 			fLowColor[3*i+1] = 1;
 			fLowColor[3*i+2] = 1;
 		}
-		attr.fHighColor = fHighColor;
-		attr.fLowColor = fLowColor;
-		attr.fBackGroundColor[0] = 0;
-		attr.fBackGroundColor[0] = 0;
-		attr.fBackGroundColor[0] = 1;
-		attr.fBackGroundColor[0] = .4;
+		aGraphAttr.fHighColor = fHighColor;
+		aGraphAttr.fLowColor = fLowColor;
+		aGraphAttr.fBackGroundColor[0] = 0;
+		aGraphAttr.fBackGroundColor[0] = 0;
+		aGraphAttr.fBackGroundColor[0] = 1;
+		aGraphAttr.fBackGroundColor[0] = .4;
 	}
-	else if (strcmp (cType, "bar") == 0)
+	else if (strcmp (cType, "progressbar") == 0)
 	{
-		/// A FAIRE...
+		memset (&aProgressBarAttr, 0, sizeof (CairoProgressBarAttribute));
+		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&aProgressBarAttr);
 	}
 	
-	if (pRenderAttr == NULL)
-		return FALSE;
+	if (pRenderAttr == NULL || iNbValues <= 0)
+	{
+		cairo_dock_remove_data_renderer_on_icon (pIcon);
+		return TRUE;
+	}
 	
+	pRenderAttr->cModelName = cType;
 	pRenderAttr->iLatencyTime = 500;  // 1/2s
 	pRenderAttr->iNbValues = iNbValues;
 	//pRenderAttr->bUpdateMinMax = TRUE;
 	//pRenderAttr->bWriteValues = TRUE;
 	g_return_val_if_fail (pIcon->pIconBuffer != NULL, FALSE);
-	if (pIcon->pDataRenderer == NULL)
-		cairo_dock_add_new_data_renderer_on_icon (pIcon, pContainer, pRenderAttr);
-	else
-		cairo_dock_reload_data_renderer_on_icon (pIcon, pContainer, pRenderAttr);
-	
+	cairo_dock_add_new_data_renderer_on_icon (pIcon, pContainer, pRenderAttr);
+
 	return TRUE;
 }
 
@@ -1027,7 +1020,7 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 	{
 		pItem = g_ptr_array_index (pItems, i);
 		
-		// on recupere ses proprietes.
+		// get its properties.
 		const gchar *cLabel = NULL, *cIcon = NULL, *cToolTip = NULL;
 		int iType = 0, iMenuID = -1, id = i, iGroupID = 0;
 		gboolean bState = FALSE;
@@ -1059,7 +1052,7 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 		else  // si on ne definit pas le groupe, c'est donc le groupe en cours qui est utilise, ou un nouveau groupe si encore aucun n'est en cours.
 			iGroupID = id;  // utilise seulement si le groupe est nouvellement cree, pour l'enregistrer.
 		
-		// on cree l'item suivant son type.
+		// create the item according to its type.
 		switch (iType)
 		{
 			case 0 :  // normal entry
@@ -1099,7 +1092,12 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 				continue;
 		}
 		
-		// on lui rajoute son icone et son tooltip.
+		// set sensitivity
+		v = g_hash_table_lookup (pItem, "sensitive");
+		if (v && G_VALUE_HOLDS_BOOLEAN (v))
+			gtk_widget_set_sensitive (pMenuItem, g_value_get_boolean (v));
+		
+		// set an icon
 		if (iType == 0 || iType == 1)
 		{
 			v = g_hash_table_lookup (pItem, "icon");
@@ -1130,6 +1128,7 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 			}
 		}
 		
+		// set the tooltip
 		v = g_hash_table_lookup (pItem, "tooltip");
 		if (v && G_VALUE_HOLDS_STRING (v))
 		{
@@ -1137,7 +1136,7 @@ gboolean cd_dbus_applet_add_menu_items (dbusApplet *pDbusApplet, GPtrArray *pIte
 			gtk_widget_set_tooltip_text (pMenuItem, cToolTip);
 		}
 		
-		// on l'insere dans son menu.
+		// insert in its menu.
 		v = g_hash_table_lookup (pItem, "menu");
 		if (v && G_VALUE_HOLDS_INT (v))
 			iMenuID = g_value_get_int (v);
@@ -1193,7 +1192,7 @@ gboolean cd_dbus_applet_bind_shortkey (dbusApplet *pDbusApplet, const gchar **cS
 	}
 	else  // just rebind, we consider that the applet wants to rebind the same shortkeys.
 	{
-		for (i = 0, kb = pDbusApplet->pShortkeyList; cShortkeys[i] != NULL, kb != NULL; i ++, kb = kb->next)
+		for (i = 0, kb = pDbusApplet->pShortkeyList; cShortkeys[i] != NULL && kb != NULL; i ++, kb = kb->next)
 		{
 			cShortkey = cShortkeys[i];
 			pKeyBinding = kb->data;
