@@ -346,7 +346,7 @@ gboolean cd_dbus_applet_emit_on_scroll_icon (gpointer data, Icon *pClickedIcon,
 
 static void _delete_menu (GtkMenuShell *menu, CairoDockModuleInstance *myApplet)
 {
-	myData.pModuleSubMenu = NULL;
+	///myData.pModuleSubMenu = NULL;
 	myData.pModuleMainMenu = NULL;
 }
 gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, CairoContainer *pClickedContainer, GtkWidget *pAppletMenu)
@@ -358,15 +358,15 @@ gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, C
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
 	myData.pModuleMainMenu = pAppletMenu;
-	myData.pModuleSubMenu = cairo_dock_create_sub_menu (pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName,
+	/**myData.pModuleSubMenu = cairo_dock_create_sub_menu (pAppletIcon->pModuleInstance->pModule->pVisitCard->cModuleName,
 		pAppletMenu,
 		pAppletIcon->pModuleInstance->pModule->pVisitCard->cIconFilePath);
 	
 	cairo_dock_add_in_menu_with_stock_and_data (_("Applet's Handbook"),
 		GTK_STOCK_ABOUT,
-		(GFunc) cairo_dock_pop_up_about_applet,
+		G_CALLBACK (cairo_dock_pop_up_about_applet),
 		myData.pModuleSubMenu,
-		pAppletIcon->pModuleInstance);
+		pAppletIcon->pModuleInstance);*/
 	
 	g_signal_connect (G_OBJECT (pAppletMenu),
 		"deactivate",
@@ -378,6 +378,10 @@ gboolean cd_dbus_applet_emit_on_build_menu (gpointer data, Icon *pClickedIcon, C
 	g_return_val_if_fail (pDbusApplet != NULL, CAIRO_DOCK_LET_PASS_NOTIFICATION);
 	myData.pCurrentMenuDbusApplet = pDbusApplet;
 	
+	GList *pChildren = gtk_container_get_children (GTK_CONTAINER (pAppletMenu));
+	myData.iMenuPosition = g_list_length (pChildren);
+	g_list_free (pChildren);
+	
 	if (pClickedIcon == pAppletIcon)
 		g_signal_emit (pDbusApplet, s_iSignals[BUILD_MENU], 0);
 	else if (pDbusApplet->pSubApplet != NULL)
@@ -406,12 +410,8 @@ gboolean cd_dbus_applet_emit_on_drop_data (gpointer data, const gchar *cReceived
 		//\________________ On telecharge l'archive de l'applet et on l'installe/la met a jour.
 		GError *erreur = NULL;
 		//g_print ("dropped a distant applet\n");
-		gchar *cServerAdress = g_path_get_dirname (cReceivedData);
-		gchar *cDistantFileName = g_path_get_basename (cReceivedData);
 		gchar *cExtractTo = g_strdup_printf ("%s/%s", g_cCairoDockDataDir, CD_DBUS_APPLETS_FOLDER);
-		gchar *cAppletDirPath = cairo_dock_download_file (cServerAdress, "", cDistantFileName, cExtractTo, &erreur);
-		g_free (cServerAdress);
-		g_free (cDistantFileName);
+		gchar *cAppletDirPath = cairo_dock_download_archive (cReceivedData, cExtractTo);
 		if (erreur != NULL)
 		{
 			cd_warning (erreur->message);
@@ -776,7 +776,7 @@ gboolean cd_dbus_emit_on_reload_module (CairoDockModuleInstance *pModuleInstance
 	}
 	
 	Icon *pIcon = pModuleInstance->pIcon;
-	if (pIcon && pIcon->cFileName == NULL && pIcon->pIconBuffer && pIcon->pDataRenderer == NULL)
+	if (pIcon && pIcon->cFileName == NULL && pIcon->pIconBuffer && (pIcon->pDataRenderer == NULL || pIcon->pDataRenderer->bUseOverlay))
 	{
 		cairo_t *pDrawContext = cairo_create (pIcon->pIconBuffer);
 		cairo_dock_set_image_on_icon (pDrawContext, pVisitCard->cIconFilePath, pIcon, pModuleInstance->pContainer);
@@ -786,19 +786,12 @@ gboolean cd_dbus_emit_on_reload_module (CairoDockModuleInstance *pModuleInstance
 	
 	if (pKeyFile == NULL)
 	{
-		if (pIcon && pIcon->pDataRenderer != NULL)
+		CairoDataRenderer *pDataRenderer = cairo_dock_get_icon_data_renderer (pIcon);
+		if (pDataRenderer != NULL)
 		{
-			cairo_dock_reload_data_renderer_on_icon (pIcon, pModuleInstance->pContainer, NULL);
-			
-			CairoDataRenderer *pRenderer = pIcon->pDataRenderer;
-			CairoDataToRenderer *pData = cairo_data_renderer_get_data (pRenderer);
-			//g_print ("actuellement %d valeurs dans l'historique\n", pData->iMemorySize);
+			CairoDataToRenderer *pData = cairo_data_renderer_get_data (pDataRenderer);
 			if (pData->iMemorySize > 2)
 				cairo_dock_resize_data_renderer_history (pIcon, pIcon->fWidth);
-			
-			cairo_t *pDrawContext = cairo_create (pIcon->pIconBuffer);
-			cairo_dock_refresh_data_renderer (pIcon, pModuleInstance->pContainer, pDrawContext);
-			cairo_destroy (pDrawContext);
 		}
 	}
 	
