@@ -122,7 +122,7 @@ void cd_do_close_session (void)
 	if (myData.iPreviouslyActiveWindow != 0)
 	{
 		/// ne le faire que si on a encore le focus, sinon c'est que l'utilisateur a change lui-meme de fenetre...
-		Window iActiveWindow = cairo_dock_get_active_xwindow ();
+		//Window iActiveWindow = cairo_dock_get_active_xwindow ();
 		
 		//cairo_dock_show_xwindow (myData.iPreviouslyActiveWindow);
 		myData.iPreviouslyActiveWindow = 0;
@@ -217,7 +217,6 @@ void cd_do_free_char_list (GList *pCharList)
 void cd_do_load_pending_caracters (void)
 {
 	cairo_surface_t *pSurface;
-	GLuint iTexture;
 	gboolean bLoadTexture = (CAIRO_CONTAINER_IS_OPENGL (g_pMainDock));
 	gchar c[2] = {'\0', '\0'};
 	CDChar *pChar;
@@ -322,7 +321,7 @@ void cd_do_delete_invalid_caracters (void)
 	
 	// on tronque la chaine de la meme maniere.
 	g_string_truncate (myData.sCurrentText, myData.iNbValidCaracters);
-	cd_debug (" -> '%s' (%d)\n", myData.sCurrentText->str, myData.iNbValidCaracters);
+	cd_debug (" -> '%s' (%d)", myData.sCurrentText->str, myData.iNbValidCaracters);
 	
 	// on remet a jour la hauteur du texte.
 	myData.iTextHeight = 0;
