@@ -28,9 +28,9 @@
 #define _XEYES_SENSITIVITY .5
 
 //\___________ Define here the entries you want to add to the menu when the user right-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons. The menu where you can add your entries is available throught the macro CD_APPLET_MY_MENU; you can add sub-menu to it if you want.
-CD_APPLET_ON_BUILD_MENU_BEGIN
+/*CD_APPLET_ON_BUILD_MENU_BEGIN
 
-CD_APPLET_ON_BUILD_MENU_END
+CD_APPLET_ON_BUILD_MENU_END*/
 
 
 CD_APPLET_ON_UPDATE_ICON_BEGIN
@@ -42,7 +42,7 @@ CD_APPLET_ON_UPDATE_ICON_BEGIN
 	gboolean bNeedsUpdate = FALSE;
 	double fScale = myIcon->fScale / cairo_dock_get_icon_max_scale (myIcon) * myContainer->fRatio;
 	int dx, dy;
-	double tana, cosa, sina, x, y;
+	double tana, cosa, sina;
 	int i;
 	for (i = 0; i < 2; i ++)
 	{
