@@ -17,12 +17,10 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
-#include "stdlib.h"
+#include "applet-struct.h"
 
 #include "applet-config.h"
 #include "applet-notifications.h"
-#include "applet-struct.h"
 #include "applet-draw.h"
 #include "applet-generic.h"
 #include "applet-init.h"
@@ -52,6 +50,7 @@ static gboolean _cd_mixer_on_enter (GtkWidget* pWidget,
 	{
 		gtk_widget_show (myData.pScale);
 	}
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 gboolean _cd_mixer_on_leave (GtkWidget* pWidget,
 	GdkEventCrossing* pEvent,
@@ -62,6 +61,44 @@ gboolean _cd_mixer_on_leave (GtkWidget* pWidget,
 		if (! myDesklet->container.bInside)
 			gtk_widget_hide (myData.pScale);
 	}
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+}
+
+static void _set_data_renderer (void)
+{
+	switch (myConfig.iVolumeEffect)
+	{
+		case VOLUME_EFFECT_GAUGE:
+		{
+			CairoDataRendererAttribute *pRenderAttr;  // les attributs du data-renderer global.
+			CairoGaugeAttribute attr;  // les attributs de la jauge.
+			memset (&attr, 0, sizeof (CairoGaugeAttribute));
+			pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
+			pRenderAttr->cModelName = "gauge";
+			pRenderAttr->iRotateTheme = myConfig.iRotateTheme;
+			attr.cThemePath = myConfig.cGThemePath;
+			
+			CD_APPLET_ADD_DATA_RENDERER_ON_MY_ICON (pRenderAttr);
+		}
+		break;
+		case VOLUME_EFFECT_BAR:
+		{
+			CD_APPLET_SET_USER_IMAGE_ON_MY_ICON (myConfig.cDefaultIcon, "default.svg");
+			
+			CairoDataRendererAttribute *pRenderAttr;  // les attributs du data-renderer global.
+			CairoProgressBarAttribute attr;
+			memset (&attr, 0, sizeof (CairoProgressBarAttribute));
+			pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
+			pRenderAttr->cModelName = "progressbar";
+			pRenderAttr->iRotateTheme = myConfig.iRotateTheme;
+
+			CD_APPLET_ADD_DATA_RENDERER_ON_MY_ICON (pRenderAttr);
+		}
+		break;
+		case VOLUME_EFFECT_NONE:
+		case VOLUME_NB_EFFECTS:
+		break;
+	}
 }
 
 CD_APPLET_INIT_BEGIN
@@ -87,23 +124,9 @@ CD_APPLET_INIT_BEGIN
 	}
 	
 	// data renderer
-	if (myConfig.iVolumeEffect == VOLUME_EFFECT_GAUGE)
-	{
-		CairoDataRendererAttribute *pRenderAttr = NULL;  // les attributs du data-renderer global.
-		CairoGaugeAttribute attr;  // les attributs de la jauge.
-		memset (&attr, 0, sizeof (CairoGaugeAttribute));
-		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
-		pRenderAttr->cModelName = "gauge";
-		pRenderAttr->iRotateTheme = myConfig.iRotateTheme;
-		attr.cThemePath = myConfig.cGThemePath;
-		
-		CD_APPLET_ADD_DATA_RENDERER_ON_MY_ICON (pRenderAttr);
-	}
-	else
-	{
-		mixer_load_surfaces ();
-	}
+	_set_data_renderer ();
 	
+	// start the sound controler
 	cd_start ();
 	
 	// mouse events
@@ -132,16 +155,12 @@ CD_APPLET_STOP_BEGIN
 	// keyboard events
 	cd_keybinder_unbind (myData.cKeyBinding);
 	
-	// stop the current controller.
+	// stop the current controler.
 	cd_stop ();
 CD_APPLET_STOP_END
 
 
 CD_APPLET_RELOAD_BEGIN
-	//\_______________ On recharge les donnees qui ont pu changer.
-	if (myConfig.iVolumeEffect != VOLUME_EFFECT_GAUGE)
-		mixer_load_surfaces ();
-	
 	//\_______________ On recharge le mixer si necessaire.
 	if (CD_APPLET_MY_CONFIG_CHANGED)
 	{
@@ -156,23 +175,9 @@ CD_APPLET_RELOAD_BEGIN
 			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF (NULL);
 		
 		// reload the data renderer
-		if (myConfig.iVolumeEffect == VOLUME_EFFECT_GAUGE)
-		{
-			CairoDataRendererAttribute *pRenderAttr = NULL;  // les attributs du data-renderer global.
-			CairoGaugeAttribute attr;  // les attributs de la jauge.
-			memset (&attr, 0, sizeof (CairoGaugeAttribute));
-			pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
-			pRenderAttr->cModelName = "gauge";
-			pRenderAttr->iRotateTheme = myConfig.iRotateTheme;
-			attr.cThemePath = myConfig.cGThemePath;
-			
-			if (cairo_dock_get_icon_data_renderer (myIcon))
-				CD_APPLET_RELOAD_MY_DATA_RENDERER (pRenderAttr);
-			else
-				CD_APPLET_ADD_DATA_RENDERER_ON_MY_ICON (pRenderAttr);
-		}
+		_set_data_renderer ();
 		
-		// reload the controller
+		// reload the controler
 		cd_reload ();
 		
 		// shortkey
@@ -246,9 +251,9 @@ CD_APPLET_RELOAD_BEGIN
 		if (myDesklet && myDesklet->container.iHeight <= 64)
 			gtk_widget_hide (myData.pScale);
 		
-		if (myConfig.iVolumeEffect == VOLUME_EFFECT_GAUGE)
+		/**if (myConfig.iVolumeEffect != VOLUME_EFFECT_NONE)
 			CD_APPLET_RELOAD_MY_DATA_RENDERER (NULL);
 		
-		cd_update_icon ();
+		cd_update_icon ();*/
 	}
 CD_APPLET_RELOAD_END
