@@ -17,9 +17,6 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
 #include <glib/gi18n.h>
 
 #include "applet-struct.h"
