@@ -38,18 +38,18 @@ static void _render_one_icon_and_quickinfo_opengl (Icon *pIcon, CairoContainer *
 			glColor4f(1., 1., 1., 1.);
 		glPopMatrix ();
 	}
-	if (pIcon->iLabelTexture != 0 && !bIsReflect)
+	if (pIcon->label.iTexture != 0 && !bIsReflect)
 	{
 		glPushMatrix ();
 			glTranslatef (0.,
-				(pIcon->fHeight + pIcon->iTextHeight)/2,
+				(pIcon->fHeight + pIcon->label.iHeight)/2,
 				0.);
-			cairo_dock_draw_texture (pIcon->iLabelTexture,
-				pIcon->iTextWidth,
-				pIcon->iTextHeight);
+			cairo_dock_draw_texture (pIcon->label.iTexture,
+				pIcon->label.iWidth,
+				pIcon->label.iHeight);
 		glPopMatrix ();
 	}
-	if (pIcon->iQuickInfoTexture != 0 && !bIsReflect)
+	/**if (pIcon->iQuickInfoTexture != 0 && !bIsReflect)
 	{
 		glPushMatrix ();
 			glTranslatef (0.,
@@ -59,6 +59,10 @@ static void _render_one_icon_and_quickinfo_opengl (Icon *pIcon, CairoContainer *
 				pIcon->iQuickInfoWidth,
 				pIcon->iQuickInfoHeight);
 		glPopMatrix ();
+	}*/
+	if (!bIsReflect)
+	{
+		cairo_dock_draw_icon_overlays_opengl (pIcon, pContainer->fRatio);
 	}
 }
 
@@ -207,6 +211,7 @@ static void free_data (CairoDesklet *pDesklet)
 	pDesklet->pRendererData = NULL;
 }
 
+/* Not used
 static void set_icon_size (CairoDesklet *pDesklet, Icon *pIcon)
 {
 	CDCarousselParameters *pCaroussel = (CDCarousselParameters *) pDesklet->pRendererData;
@@ -241,7 +246,7 @@ static void set_icon_size (CairoDesklet *pDesklet, Icon *pIcon)
 		}
 	}
 }
-
+*/
 static void calculate_icons (CairoDesklet *pDesklet)
 {
 	CDCarousselParameters *pCaroussel = (CDCarousselParameters *) pDesklet->pRendererData;
@@ -350,7 +355,6 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 		
 		//\____________________ On trace le cadre.
 		double fLineWidth = myDocksParam.iDockLineWidth;
-		double fMargin = 0;
 		
 		double fDockWidth = pDesklet->container.iWidth - fExtraWidth;
 		int sens=1;
@@ -522,7 +526,7 @@ static void render_opengl (CairoDesklet *pDesklet)
 	double a = pCaroussel->a, b = pCaroussel->b;
 
 	Icon *pIcon;
-	GList *ic, *ic2;
+	GList *ic;
 
 	if (pCaroussel->b3D)
 	{
