@@ -127,7 +127,7 @@ static void free_data (CairoDesklet *pDesklet)
 	pDesklet->pRendererData = NULL;
 }
 
-
+/* Not used
 static void set_icon_size (CairoDesklet *pDesklet, Icon *pIcon)
 {
 	CDPanelParameters *pPanel = (CDPanelParameters *) pDesklet->pRendererData;
@@ -145,6 +145,7 @@ static void set_icon_size (CairoDesklet *pDesklet, Icon *pIcon)
 		pIcon->fHeight = pPanel->iIconSize;
 	}
 }
+*/
 
 static void calculate_icons (CairoDesklet *pDesklet)
 {
@@ -153,7 +154,7 @@ static void calculate_icons (CairoDesklet *pDesklet)
 		return ;
 	
 	_compute_icons_grid (pDesklet, pPanel);
-	cd_debug ("pPanel->iIconSize : %d\n", pPanel->iIconSize);
+	cd_debug ("pPanel->iIconSize : %d", pPanel->iIconSize);
 	
 	Icon *pIcon = pDesklet->pIcon;
 	if (pIcon != NULL)
@@ -304,7 +305,7 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 		else
 			cairo_paint_with_alpha (pCairoContext, pIcon->fAlpha);
 			
-		if (pIcon->pQuickInfoBuffer != NULL)
+		/**if (pIcon->pQuickInfoBuffer != NULL)
 		{
 			cairo_translate (pCairoContext,
 				pIcon->fDrawX + pIcon->fWidth,
@@ -315,7 +316,8 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 				0,
 				0);
 			cairo_paint (pCairoContext);
-		}
+		}*/
+		cairo_dock_draw_icon_overlays_cairo (pIcon, pDesklet->container.fRatio, pCairoContext);
 		cairo_restore (pCairoContext);
 	}
 	
@@ -339,7 +341,7 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 			
 			cairo_restore (pCairoContext);
 			
-			if (pIcon->pTextBuffer != NULL)
+			if (pIcon->label.pSurface != NULL)
 			{
 				cairo_save (pCairoContext);
 				cairo_translate (pCairoContext, pIcon->fDrawX, pIcon->fDrawY);
@@ -348,16 +350,16 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 				if (pIcon->bPointed)
 				{
 					fAlpha = 1.;
-					/**if (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->iTextWidth/2 > pDesklet->container.iWidth)
-						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->iTextWidth/2);
-					if (pIcon->fDrawX + pIcon->fWidth/2 - pIcon->iTextWidth/2 < 0)
-						fOffsetX = pIcon->iTextWidth/2 - (pIcon->fDrawX + pIcon->fWidth/2);
+					/**if (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->label.iWidth/2 > pDesklet->container.iWidth)
+						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->label.iWidth/2);
+					if (pIcon->fDrawX + pIcon->fWidth/2 - pIcon->label.iWidth/2 < 0)
+						fOffsetX = pIcon->label.iWidth/2 - (pIcon->fDrawX + pIcon->fWidth/2);
 					cairo_set_source_surface (pCairoContext,
-						pIcon->pTextBuffer,
-						fOffsetX + pIcon->fWidth/2 - pIcon->iTextWidth/2,
+						pIcon->label.pSurface,
+						fOffsetX + pIcon->fWidth/2 - pIcon->label.iWidth/2,
 						-myIconsParam.iLabelSize);*/
 					cairo_set_source_surface (pCairoContext,
-						pIcon->pTextBuffer,
+						pIcon->label.pSurface,
 						0.,
 						-myIconsParam.iLabelSize);
 					cairo_paint_with_alpha (pCairoContext, fAlpha);
@@ -365,7 +367,7 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 				else
 				{
 					fAlpha = .6;
-					if (pIcon->iTextWidth > 2*pIcon->fWidth + 0 * myIconsParam.iLabelSize)
+					if (pIcon->label.iWidth > 2*pIcon->fWidth + 0 * myIconsParam.iLabelSize)
 					{
 						///fOffsetX = - myIconsParam.iLabelSize;
 						cairo_pattern_t *pGradationPattern = cairo_pattern_create_linear (fOffsetX,
@@ -392,7 +394,7 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 							0.,
 							0.);
 						cairo_set_source_surface (pCairoContext,
-							pIcon->pTextBuffer,
+							pIcon->label.pSurface,
 							fOffsetX,
 							-myIconsParam.iLabelSize);
 						cairo_mask (pCairoContext, pGradationPattern);
@@ -400,9 +402,9 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 					}
 					else
 					{
-						///fOffsetX = pIcon->fWidth/2 - pIcon->iTextWidth/2;
+						///fOffsetX = pIcon->fWidth/2 - pIcon->label.iWidth/2;
 						cairo_set_source_surface (pCairoContext,
-							pIcon->pTextBuffer,
+							pIcon->label.pSurface,
 							fOffsetX,
 							-myIconsParam.iLabelSize);
 						cairo_paint_with_alpha (pCairoContext, fAlpha);
@@ -412,7 +414,7 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 				cairo_restore (pCairoContext);
 			}
 			
-			if (pIcon->pQuickInfoBuffer != NULL)
+			/**if (pIcon->pQuickInfoBuffer != NULL)
 			{
 				cairo_save (pCairoContext);
 				
@@ -427,7 +429,8 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 				cairo_paint (pCairoContext);
 				
 				cairo_restore (pCairoContext);
-			}
+			}*/
+			cairo_dock_draw_icon_overlays_cairo (pIcon, pDesklet->container.fRatio, pCairoContext);
 		}
 		ic = cairo_dock_get_next_element (ic, pDesklet->icons);
 	}
@@ -447,8 +450,8 @@ static void render_opengl (CairoDesklet *pDesklet)
 	// draw frame
 	double fRadius = pPanel->iRadius;
 	double fLineWidth = pPanel->iLineWidth;
-	double fOffsetX = fRadius + fLineWidth/2;
-	double fOffsetY = fLineWidth/2;
+	//double fOffsetX = fRadius + fLineWidth/2;
+	//double fOffsetY = fLineWidth/2;
 	double fFrameWidth = pDesklet->container.iWidth - 2 * fRadius - fLineWidth;
 	double fFrameHeight = pDesklet->container.iHeight - 2 * fRadius - fLineWidth;
 	double w = fFrameWidth / 2;
@@ -506,7 +509,7 @@ static void render_opengl (CairoDesklet *pDesklet)
 			0.);
 		_cairo_dock_apply_texture_at_size (pIcon->iIconTexture, pIcon->fWidth, pIcon->fHeight);
 		
-		if (pIcon->iQuickInfoTexture != 0)
+		/**if (pIcon->iQuickInfoTexture != 0)
 		{
 			glPushMatrix ();
 			double dx = .5 * (pIcon->iQuickInfoWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
@@ -518,7 +521,8 @@ static void render_opengl (CairoDesklet *pDesklet)
 				pIcon->iQuickInfoWidth,
 				pIcon->iQuickInfoHeight);
 			glPopMatrix ();
-		}
+		}*/
+		cairo_dock_draw_icon_overlays_opengl (pIcon, pDesklet->container.fRatio);
 		
 		glPopMatrix ();
 	}
@@ -540,47 +544,48 @@ static void render_opengl (CairoDesklet *pDesklet)
 				floor (pDesklet->container.iHeight - pIcon->fDrawY - pIcon->fHeight/2),
 				0.);
 			
+			_cairo_dock_enable_texture ();  // cairo_dock_draw_icon_overlays_opengl() disable textures
 			_cairo_dock_apply_texture_at_size (pIcon->iIconTexture, pIcon->fWidth, pIcon->fHeight);
 			
-			if (pIcon->iLabelTexture != 0)
+			if (pIcon->label.iTexture != 0)
 			{
 				glPushMatrix ();
 				
-				double dx = .5 * (pIcon->iTextWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
-				double dy = .5 * (pIcon->iTextHeight & 1);
+				double dx = .5 * (pIcon->label.iWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
+				double dy = .5 * (pIcon->label.iHeight & 1);
 				double u0 = 0., u1 = 1.;
 				double fOffsetX = 0.;
 				if (pIcon->bPointed)
 				{
 					_cairo_dock_set_alpha (1.);
-					if (pIcon->fDrawX + pIcon->fWidth + pIcon->iTextWidth/2 > pDesklet->container.iWidth)
-						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth + pIcon->iTextWidth/2);
-					if (pIcon->fDrawX + pIcon->fWidth - pIcon->iTextWidth/2 < 0)
-						fOffsetX = pIcon->iTextWidth/2 - (pIcon->fDrawX + pIcon->fWidth);
+					if (pIcon->fDrawX + pIcon->fWidth + pIcon->label.iWidth/2 > pDesklet->container.iWidth)
+						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth + pIcon->label.iWidth/2);
+					if (pIcon->fDrawX + pIcon->fWidth - pIcon->label.iWidth/2 < 0)
+						fOffsetX = pIcon->label.iWidth/2 - (pIcon->fDrawX + pIcon->fWidth);
 				}
 				else
 				{
 					_cairo_dock_set_alpha (.6);
-					if (pIcon->iTextWidth > 2*pIcon->fWidth + 2 * myIconsParam.iLabelSize)
+					if (pIcon->label.iWidth > 2*pIcon->fWidth + 2 * myIconsParam.iLabelSize)
 					{
 						fOffsetX = 0.;
-						u1 = (double) (2*pIcon->fWidth + 2 * myIconsParam.iLabelSize) / pIcon->iTextWidth;
+						u1 = (double) (2*pIcon->fWidth + 2 * myIconsParam.iLabelSize) / pIcon->label.iWidth;
 					}
 				}
 				
-				glTranslatef (ceil (-pIcon->fWidth/2 + fOffsetX + pIcon->iTextWidth/2) + dx, ceil (pIcon->fHeight/2 + pIcon->iTextHeight / 2) + dy, 0.);
+				glTranslatef (ceil (-pIcon->fWidth/2 + fOffsetX + pIcon->label.iWidth/2) + dx, ceil (pIcon->fHeight/2 + pIcon->label.iHeight / 2) + dy, 0.);
 				
-				glBindTexture (GL_TEXTURE_2D, pIcon->iLabelTexture);
+				glBindTexture (GL_TEXTURE_2D, pIcon->label.iTexture);
 				_cairo_dock_apply_current_texture_portion_at_size_with_offset (u0, 0.,
 					u1 - u0, 1.,
-					pIcon->iTextWidth * (u1 - u0), pIcon->iTextHeight,
+					pIcon->label.iWidth * (u1 - u0), pIcon->label.iHeight,
 					0., 0.);
 				_cairo_dock_set_alpha (1.);
 				
 				glPopMatrix ();
 			}
 			
-			if (pIcon->iQuickInfoTexture != 0)
+			/**if (pIcon->iQuickInfoTexture != 0)
 			{
 				double dx = .5 * (pIcon->iQuickInfoWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
 				double dy = .5 * (pIcon->iQuickInfoHeight & 1);
@@ -591,7 +596,8 @@ static void render_opengl (CairoDesklet *pDesklet)
 				_cairo_dock_apply_texture_at_size (pIcon->iQuickInfoTexture,
 					pIcon->iQuickInfoWidth,
 					pIcon->iQuickInfoHeight);
-			}
+			}*/
+			cairo_dock_draw_icon_overlays_opengl (pIcon, pDesklet->container.fRatio);
 			
 			glPopMatrix ();
 		}
