@@ -26,7 +26,7 @@
 static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet);
 
 
-static inline void _get_gridXY_from_index (guint nRowsX, guint index, guint* gridX, guint* gridY)
+static inline void _get_gridXY_from_index (gint nRowsX, gint index, gint* gridX, gint* gridY)
 {
 	*gridX = index % nRowsX;
 	*gridY = index / nRowsX;
@@ -94,8 +94,8 @@ static void _compute_icons_position (CairoDesklet *pDesklet, CDViewportParameter
 		fScrollOffset;
 	
 	Icon* icon;
-	GList* ic, *pointed_ic=NULL;
-	int i, x, y;
+	GList* ic;
+	gint i, x, y;
 	for (ic = pDesklet->icons, i = 0; ic != NULL; ic = ic->next, i++)
 	{
 		icon = ic->data;
@@ -215,7 +215,7 @@ static gboolean _cd_slide_on_mouse_moved (gpointer data, CairoDesklet *pDesklet,
 		double y_arrow_top = 2., y_arrow_bottom = pDesklet->container.iHeight - 2.;  // on laisse 2 pixels de marge.
 		double fFrameHeight = pDesklet->container.iHeight;  // hauteur du cadre.
 		double fGripHeight = fFrameHeight / (fFrameHeight + pData->iDeltaHeight) * (y_arrow_bottom - y_arrow_top - 2*(pData->fArrowHeight + pData->fScrollbarArrowGap));
-		double ygrip = (double) pData->iScrollOffset / pData->iDeltaHeight * (y_arrow_bottom - y_arrow_top - 2*(pData->fArrowHeight + pData->fScrollbarArrowGap) - fGripHeight);
+		// double ygrip = (double) pData->iScrollOffset / pData->iDeltaHeight * (y_arrow_bottom - y_arrow_top - 2*(pData->fArrowHeight + pData->fScrollbarArrowGap) - fGripHeight);
 		
 		int delta = pDesklet->container.iMouseY - pData->iClickY;
 		_set_scroll (pDesklet, (pData->iClickOffset + (double)delta / (y_arrow_bottom - y_arrow_top - 2*(pData->fArrowHeight + pData->fScrollbarArrowGap) - fGripHeight) * pData->iDeltaHeight));
@@ -285,7 +285,7 @@ static void free_data (CairoDesklet *pDesklet)
 	pDesklet->pRendererData = NULL;
 }
 
-
+/* Not used
 static void set_icon_size (CairoDesklet *pDesklet, Icon *pIcon)
 {
 	CDViewportParameters *pViewport = (CDViewportParameters *) pDesklet->pRendererData;
@@ -303,7 +303,7 @@ static void set_icon_size (CairoDesklet *pDesklet, Icon *pIcon)
 		pIcon->fHeight = pViewport->iIconSize;
 	}
 }
-
+*/
 
 static void calculate_icons (CairoDesklet *pDesklet)
 {
@@ -335,7 +335,9 @@ static void calculate_icons (CairoDesklet *pDesklet)
 		{
 			pIcon->fWidth = pViewport->iIconSize;
 			pIcon->fHeight = pViewport->iIconSize;
-		
+			pIcon->iImageWidth = pIcon->fWidth;
+			pIcon->iImageHeight = pIcon->fHeight;
+			
 			pIcon->fScale = 1.;
 			pIcon->fAlpha = 1.;
 			pIcon->fWidthFactor = 1.;
@@ -432,11 +434,11 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 		{
 			cairo_save (pCairoContext);
 			
-			cairo_dock_render_one_icon_in_desklet (pIcon, pCairoContext, FALSE, FALSE, pDesklet->container.iWidth);
+			cairo_dock_render_one_icon_in_desklet (pIcon, CAIRO_CONTAINER (pDesklet), pCairoContext, FALSE);
 			
 			cairo_restore (pCairoContext);
 			
-			if (pIcon->pTextBuffer != NULL)
+			if (pIcon->label.pSurface != NULL)
 			{
 				cairo_save (pCairoContext);
 				cairo_translate (pCairoContext, pIcon->fDrawX, pIcon->fDrawY);
@@ -445,20 +447,20 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 				if (pIcon->bPointed)
 				{
 					fAlpha = 1.;
-					if (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->iTextWidth/2 > pDesklet->container.iWidth)
-						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->iTextWidth/2);
-					if (pIcon->fDrawX + pIcon->fWidth/2 - pIcon->iTextWidth/2 < 0)
-						fOffsetX = pIcon->iTextWidth/2 - (pIcon->fDrawX + pIcon->fWidth/2);
+					if (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->label.iWidth/2 > pDesklet->container.iWidth)
+						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->label.iWidth/2);
+					if (pIcon->fDrawX + pIcon->fWidth/2 - pIcon->label.iWidth/2 < 0)
+						fOffsetX = pIcon->label.iWidth/2 - (pIcon->fDrawX + pIcon->fWidth/2);
 					cairo_set_source_surface (pCairoContext,
-						pIcon->pTextBuffer,
-						fOffsetX + pIcon->fWidth/2 - pIcon->iTextWidth/2,
+						pIcon->label.pSurface,
+						fOffsetX + pIcon->fWidth/2 - pIcon->label.iWidth/2,
 						-myIconsParam.iLabelSize);
 					cairo_paint_with_alpha (pCairoContext, fAlpha);
 				}
 				else
 				{
 					fAlpha = .6;
-					if (pIcon->iTextWidth > pIcon->fWidth + 2 * myIconsParam.iLabelSize)
+					if (pIcon->label.iWidth > pIcon->fWidth + 2 * myIconsParam.iLabelSize)
 					{
 						fOffsetX = - myIconsParam.iLabelSize;
 						cairo_pattern_t *pGradationPattern = cairo_pattern_create_linear (fOffsetX,
@@ -485,7 +487,7 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 							0.,
 							0.);
 						cairo_set_source_surface (pCairoContext,
-							pIcon->pTextBuffer,
+							pIcon->label.pSurface,
 							fOffsetX,
 							-myIconsParam.iLabelSize);
 						cairo_mask (pCairoContext, pGradationPattern);
@@ -493,9 +495,9 @@ static void render (cairo_t *pCairoContext, CairoDesklet *pDesklet)
 					}
 					else
 					{
-						fOffsetX = pIcon->fWidth/2 - pIcon->iTextWidth/2;
+						fOffsetX = pIcon->fWidth/2 - pIcon->label.iWidth/2;
 						cairo_set_source_surface (pCairoContext,
-							pIcon->pTextBuffer,
+							pIcon->label.pSurface,
 							fOffsetX,
 							-myIconsParam.iLabelSize);
 						cairo_paint_with_alpha (pCairoContext, fAlpha);
@@ -614,55 +616,57 @@ static void render_opengl (CairoDesklet *pDesklet)
 				pDesklet->container.iHeight - pIcon->fDrawY - pIcon->fHeight/2,
 				0.);
 			//g_print (" %d) %d;%d %dx%d\n", pIcon->iIconTexture, (int)(pIcon->fDrawX + pIcon->fWidth/2), (int)(pDesklet->container.iHeight - pIcon->fDrawY - pIcon->fHeight/2), (int)(pIcon->fWidth/2), (int)(pIcon->fHeight/2));
+			_cairo_dock_enable_texture ();  // cairo_dock_draw_icon_overlays_opengl() disable textures
 			_cairo_dock_apply_texture_at_size (pIcon->iIconTexture, pIcon->fWidth, pIcon->fHeight);
 			
 			/// generer une notification ...
-			if (pIcon->iLabelTexture != 0)
+			if (pIcon->label.iTexture != 0)
 			{
 				glPushMatrix ();
 				
-				double dx = .5 * (pIcon->iTextWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
-				double dy = .5 * (pIcon->iTextHeight & 1);
+				double dx = .5 * (pIcon->label.iWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
+				double dy = .5 * (pIcon->label.iHeight & 1);
 				double u0 = 0., u1 = 1.;
 				double fOffsetX = 0.;
 				if (pIcon->bPointed)
 				{
 					_cairo_dock_set_alpha (1.);
-					if (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->iTextWidth/2 > pDesklet->container.iWidth)
-						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->iTextWidth/2);
-					if (pIcon->fDrawX + pIcon->fWidth/2 - pIcon->iTextWidth/2 < 0)
-						fOffsetX = pIcon->iTextWidth/2 - (pIcon->fDrawX + pIcon->fWidth/2);
+					if (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->label.iWidth/2 > pDesklet->container.iWidth)
+						fOffsetX = pDesklet->container.iWidth - (pIcon->fDrawX + pIcon->fWidth/2 + pIcon->label.iWidth/2);
+					if (pIcon->fDrawX + pIcon->fWidth/2 - pIcon->label.iWidth/2 < 0)
+						fOffsetX = pIcon->label.iWidth/2 - (pIcon->fDrawX + pIcon->fWidth/2);
 				}
 				else
 				{
 					_cairo_dock_set_alpha (.6);
-					if (pIcon->iTextWidth > pIcon->fWidth + 2 * myIconsParam.iLabelSize)
+					if (pIcon->label.iWidth > pIcon->fWidth + 2 * myIconsParam.iLabelSize)
 					{
 						fOffsetX = 0.;
-						u1 = (double) (pIcon->fWidth + 2 * myIconsParam.iLabelSize) / pIcon->iTextWidth;
+						u1 = (double) (pIcon->fWidth + 2 * myIconsParam.iLabelSize) / pIcon->label.iWidth;
 					}
 				}
 				
-				glTranslatef (ceil (fOffsetX) + dx, ceil (pIcon->fHeight/2 + pIcon->iTextHeight / 2) + dy, 0.);
+				glTranslatef (ceil (fOffsetX) + dx, ceil (pIcon->fHeight/2 + pIcon->label.iHeight / 2) + dy, 0.);
 				
-				glBindTexture (GL_TEXTURE_2D, pIcon->iLabelTexture);
+				glBindTexture (GL_TEXTURE_2D, pIcon->label.iTexture);
 				_cairo_dock_apply_current_texture_portion_at_size_with_offset (u0, 0.,
 					u1 - u0, 1.,
-					pIcon->iTextWidth * (u1 - u0), pIcon->iTextHeight,
+					pIcon->label.iWidth * (u1 - u0), pIcon->label.iHeight,
 					0., 0.);
 				_cairo_dock_set_alpha (1.);
 				
 				glPopMatrix ();
 			}
 			
-			if (pIcon->iQuickInfoTexture != 0)
+			/**if (pIcon->iQuickInfoTexture != 0)
 			{
 				glTranslatef (0., (- pIcon->fHeight + pIcon->iQuickInfoHeight)/2, 0.);
 				
 				_cairo_dock_apply_texture_at_size (pIcon->iQuickInfoTexture,
 					pIcon->iQuickInfoWidth,
 					pIcon->iQuickInfoHeight);
-			}
+			}*/
+			cairo_dock_draw_icon_overlays_opengl (pIcon, pDesklet->container.fRatio);
 			
 			glPopMatrix ();
 		}
