@@ -246,6 +246,8 @@ static gboolean _cd_dnd2share_update_from_result (CDSharedMemory *pSharedMemory)
 				{
 					gchar *cCommand = g_strdup_printf ("cp '%s' '%s/%s'", cFilePath, myData.cWorkingDirPath, cItemName);
 					int r = system (cCommand);
+					if (r < 0)
+						cd_warning ("Not able to launch this command: %s", cCommand);
 					g_free (cCommand);
 				}
 			}
@@ -344,13 +346,21 @@ void cd_dnd2share_launch_upload (const gchar *cFilePath, CDFileType iFileType)
 	
 	// launch the task.
 	CDSharedMemory *pSharedMemory = g_new0 (CDSharedMemory, 1);
+	gboolean bIsPath = FALSE; // we can receive text or a text file
 	if (strncmp (cFilePath, "file://", 7) == 0)
+	{
+		cd_debug ("FilePath: %s", cFilePath);
 		cFilePath += 7;
+		bIsPath = TRUE;
+	}
+	else if (iFileType == CD_TYPE_TEXT && *cFilePath == '/' && g_file_test (cFilePath, G_FILE_TEST_EXISTS))
+		bIsPath = TRUE;
+
 	gchar *cTmpFile = NULL;
 	if (myConfig.bUseOnlyFileType)
 	{
 		// for a piece of text, write it in a temporary file and upload this one.
-		if (iFileType == CD_TYPE_TEXT)
+		if (iFileType == CD_TYPE_TEXT && ! bIsPath)
 		{
 			// make a filename based on the upload date.
 			cTmpFile = g_new0 (gchar, CD_BUFFER_LENGTH+1);
@@ -376,7 +386,30 @@ void cd_dnd2share_launch_upload (const gchar *cFilePath, CDFileType iFileType)
 	{
 		pSharedMemory->iCurrentFileType = iFileType;
 	}
-	pSharedMemory->cCurrentFilePath = g_strdup (cFilePath);
+
+	// If we drop a text file, we have an URI but we want to post the content to a website
+	if (pSharedMemory->iCurrentFileType == CD_TYPE_TEXT && bIsPath)
+	{
+		cd_debug ("Type is text and it's a file: %s", cFilePath);
+		gchar *cContents = NULL;
+		gsize iLength;
+		g_file_get_contents (cFilePath, &cContents, &iLength, NULL);
+		if (cContents == NULL)  // file was not readable, abort.
+		{
+			cd_warning ("file not readable !");
+			cairo_dock_remove_dialog_if_any (myIcon);
+			cairo_dock_show_temporary_dialog_with_icon (D_("This file is not readable."),
+				myIcon,
+				myContainer,
+				myConfig.dTimeDialogs,
+				MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
+			return ;
+		}
+		pSharedMemory->cCurrentFilePath = cContents;
+	}
+	else
+		pSharedMemory->cCurrentFilePath = g_strdup (cFilePath);
+
 	g_free (cTmpFile);
 	
 	pSharedMemory->iTinyURLService = myConfig.iTinyURLService;
@@ -408,6 +441,8 @@ void cd_dnd2share_clear_working_directory (void)
 	g_return_if_fail (myData.cWorkingDirPath != NULL && *myData.cWorkingDirPath == '/');
 	gchar *cCommand = g_strdup_printf ("rm -rf '%s'/*", myData.cWorkingDirPath);
 	int r = system (cCommand);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", cCommand);
 	g_free (cCommand);
 	
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s", myData.cWorkingDirPath, "history.conf");
@@ -426,6 +461,8 @@ void cd_dnd2share_clear_copies_in_working_directory (void)
 	g_return_if_fail (myData.cWorkingDirPath != NULL && *myData.cWorkingDirPath == '/');
 	gchar *cCommand = g_strdup_printf ("find '%s' -mindepth 1 ! -name *.conf -exec rm -f '{}' \\;", myData.cWorkingDirPath);
 	int r = system (cCommand);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", cCommand);
 	g_free (cCommand);
 }
 
