@@ -25,11 +25,11 @@
 #include "applet-draw.h"
 
 
-void cd_xkbd_update_icon (const gchar *cGroupName, const gchar *cShortGroupName, const gchar *cIndicatorName, gboolean bRedrawSurface)
+void cd_xkbd_update_icon (const gchar *cGroupName, const gchar *cShortGroupName, gboolean bRedrawSurface)
 {
 	//g_print ("%s (%s;%s;%d)\n", __func__, cGroupName, cShortGroupName, bRedrawSurface);
 	
-	if (bRedrawSurface)
+	if (bRedrawSurface)  // group has changed -> update the icon and label
 	{
 		//\__________________ On sauvegarde l'ancienne surface/texture.
 		if (myData.pOldSurface != NULL)
@@ -52,14 +52,12 @@ void cd_xkbd_update_icon (const gchar *cGroupName, const gchar *cShortGroupName,
 			myData.iCurrentTextHeight = 0;
 			return;
 		}
-		double fMaxScale = cairo_dock_get_max_scale (myContainer);
 		myData.pCurrentSurface = cairo_dock_create_surface_from_text_full (cShortGroupName,
 			&myConfig.textDescription,
-			fMaxScale,
-			iWidth,
-			&myData.iCurrentTextWidth, &myData.iCurrentTextHeight, NULL, NULL);
-		myData.iCurrentTextWidth *= fMaxScale;
-		myData.iCurrentTextHeight *= fMaxScale;
+			1.,
+			0*iWidth,
+			&myData.iCurrentTextWidth, &myData.iCurrentTextHeight);
+		cd_debug ("KEYBOARD: %dx%d / %dx%d", myData.iCurrentTextWidth, myData.iCurrentTextHeight, myIcon->iImageWidth, myIcon->iImageHeight);
 		if (g_bUseOpenGL)
 		{
 			myData.iCurrentTexture = cairo_dock_create_texture_from_surface (myData.pCurrentSurface);
@@ -85,20 +83,60 @@ void cd_xkbd_update_icon (const gchar *cGroupName, const gchar *cShortGroupName,
 			else
 			{
 				cd_xkbd_render_step_cairo (myIcon, myApplet);
-				CD_APPLET_UPDATE_REFLECT_ON_MY_ICON;
+				///CD_APPLET_UPDATE_REFLECT_ON_MY_ICON;
 			}
 			CD_APPLET_REDRAW_MY_ICON;
 		}
 		
-		//\__________________ On met a jour le reste.
+		//\__________________ update the label.
 		CD_APPLET_SET_NAME_FOR_MY_ICON (cGroupName);
-		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON (cIndicatorName);
 	}
-	else
+	else  // only the indicators have changed -> trigger a redraw event only  (overlay update).
 	{
-		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON (!cIndicatorName || *cIndicatorName == '\0' ? NULL : cIndicatorName);
 		CD_APPLET_REDRAW_MY_ICON;
 	}
+	
+	//\__________________ lock indicators
+	if (myConfig.bShowKbdIndicator)
+	{
+		cd_debug ("XKBD: caps-lock: %d; num-lock: %d", myData.iCurrentIndic & 1, myData.iCurrentIndic & 2);
+		if (myData.iCurrentIndic & 1)  // caps-lock
+		{
+			if (! (myData.iPreviousIndic & 1)) // TODO: cairo_dock_search_icon_s_path in init? or here the first time (save to data) and reset in reload?
+			{
+				if (myConfig.cEmblemCapsLock && (myData.cEmblemCapsLock ||
+					(myData.cEmblemCapsLock = cairo_dock_search_icon_s_path (myConfig.cEmblemCapsLock, // search for an icon only the first time
+						MAX (myIcon->iImageWidth/2, myIcon->iImageHeight/2)))))
+					CD_APPLET_ADD_OVERLAY_ON_MY_ICON (myData.cEmblemCapsLock, CAIRO_OVERLAY_UPPER_RIGHT);
+				else
+					CD_APPLET_ADD_OVERLAY_ON_MY_ICON (MY_APPLET_SHARE_DATA_DIR"/caps-lock.png", CAIRO_OVERLAY_UPPER_RIGHT);
+			}
+		}
+		else
+		{
+			if (myData.iPreviousIndic & 1)
+				CD_APPLET_REMOVE_OVERLAY_ON_MY_ICON (CAIRO_OVERLAY_UPPER_RIGHT);
+		}
+
+		if (myData.iCurrentIndic & 2)  // num-lock
+		{
+			if (! (myData.iPreviousIndic & 2))
+			{
+				if (myConfig.cEmblemNumLock &&(myData.cEmblemNumLock ||
+					(myData.cEmblemNumLock = cairo_dock_search_icon_s_path (myConfig.cEmblemNumLock,
+						MAX (myIcon->iImageWidth/2, myIcon->iImageHeight/2)))))
+					CD_APPLET_ADD_OVERLAY_ON_MY_ICON (myData.cEmblemNumLock, CAIRO_OVERLAY_UPPER_LEFT);
+				else
+					CD_APPLET_ADD_OVERLAY_ON_MY_ICON (MY_APPLET_SHARE_DATA_DIR"/num-lock.png", CAIRO_OVERLAY_UPPER_LEFT);
+			}
+		}
+		else
+		{
+			if (myData.iPreviousIndic & 2)
+				CD_APPLET_REMOVE_OVERLAY_ON_MY_ICON (CAIRO_OVERLAY_UPPER_LEFT);
+		}
+		myData.iPreviousIndic = myData.iCurrentIndic;
+	}
 }
 
 
@@ -106,12 +144,11 @@ gboolean cd_xkbd_render_step_opengl (Icon *pIcon, CairoDockModuleInstance *myApp
 {
 	CD_APPLET_ENTER;
 	double f = CD_APPLET_GET_TRANSITION_FRACTION ();
-	//g_print ("%s (%.2f; %.2fx%.2f)\n", __func__, f, myIcon->fWidth, myIcon->fHeight);
+	cd_debug ("%s (%.2f; %.2fx%.2f)", __func__, f, myIcon->fWidth, myIcon->fHeight);
 	
 	int iWidth, iHeight;
 	CD_APPLET_GET_MY_ICON_EXTENT (&iWidth, &iHeight);
 	
-	///cairo_dock_set_perspective_view (iWidth, iHeight);
 	cairo_dock_set_perspective_view_for_icon (myIcon, myContainer);
 	glScalef (1., -1., 1.);
 	
@@ -120,29 +157,47 @@ gboolean cd_xkbd_render_step_opengl (Icon *pIcon, CairoDockModuleInstance *myApp
 	_cairo_dock_set_alpha (1.);
 	
 	// fond
-	if (myData.iBackgroundTexture != 0)
-		cairo_dock_apply_texture_at_size (myData.iBackgroundTexture, iWidth, iHeight);
+	if (myData.bgImage.iTexture != 0)
+		cairo_dock_apply_texture_at_size (myData.bgImage.iTexture, iWidth, iHeight);
 	
 	double fTheta = - 45. + f * 90.;  // -45 -> 45
 	glTranslatef (0., 0., - iWidth * sqrt(2)/2 * cos (fTheta/180.*G_PI));  // pour faire tenir le cube dans la fenetre.
 	glEnable (GL_DEPTH_TEST);
 	
 	// image precedente.
+	int w=0, h;
 	if (fTheta < 25 && myData.iOldTexture != 0)  // inutile de dessiner si elle est derriere l'image courante, par l'effet de perspective (en fait 22.5, mais bizarrement ca a l'air un peu trop tot).
 	{
+		w = iWidth * myConfig.fTextRatio;  // fill horizontally
+		h = myData.iOldTextHeight * (double)w/myData.iOldTextWidth;  // keep ratio
+		if (h > iHeight * myConfig.fTextRatio)
+		{
+			w *= iHeight * myConfig.fTextRatio / h;
+			h = iHeight * myConfig.fTextRatio;
+		}
+		
 		glPushMatrix ();
 		glRotatef (45. + fTheta, 0., 1., 0.);  // 0 -> 90
-		glTranslatef (0., 0., (myData.iCurrentTextWidth ? myData.iCurrentTextWidth : iWidth)/2);
-		cairo_dock_apply_texture_at_size (myData.iOldTexture, myData.iOldTextWidth, MIN (iHeight, myData.iOldTextHeight));
+		glTranslatef (0., (-iHeight + h)/2, w/2);  // H center, V bottom
+		cairo_dock_apply_texture_at_size (myData.iOldTexture, w, h);
 		glPopMatrix ();
 	}
 	
 	// image courante a 90deg.
-	glRotatef (45. + fTheta, 0., 1., 0.);  // 0 -> 90
-	glTranslatef (- (myData.iOldTextWidth ? myData.iOldTextWidth : iWidth)/2, 0., 0.);
-	
-	glRotatef (-90., 0., 1., 0.);
-	cairo_dock_apply_texture_at_size (myData.iCurrentTexture, myData.iCurrentTextWidth, MIN (iHeight, myData.iCurrentTextHeight));
+	w = iWidth * myConfig.fTextRatio;  // fill horizontally
+	h = myData.iCurrentTextHeight * (double)w/myData.iCurrentTextWidth;  // keep ratio
+	if (h > iHeight * myConfig.fTextRatio)
+	{
+		w *= iHeight * myConfig.fTextRatio / h;
+		h = iHeight * myConfig.fTextRatio;
+	}
+
+	/**glRotatef (45. + fTheta, 0., 1., 0.);  // 0 -> 90
+	glTranslatef (- (w ? w : iWidth)/2, 0., 0.);
+	glRotatef (-90., 0., 1., 0.);*/
+	glRotatef (-45. + fTheta, 0., 1., 0.);  // -90 -> 0
+	glTranslatef (0., (-iHeight + h)/2, w/2);  // H center, V bottom
+	cairo_dock_apply_texture_at_size (myData.iCurrentTexture, w, h);
 	
 	glDisable (GL_DEPTH_TEST);
 	_cairo_dock_disable_texture ();
@@ -168,61 +223,59 @@ gboolean cd_xkbd_render_step_cairo (Icon *pIcon, CairoDockModuleInstance *myAppl
 	
 	cairo_dock_erase_cairo_context (myDrawContext);
 	
-	if (myData.pBackgroundSurface != NULL)
+	if (myData.bgImage.pSurface != NULL)
 	{
 		cairo_set_source_surface (
 			myDrawContext,
-			myData.pBackgroundSurface,
+			myData.bgImage.pSurface,
 			0.,
 			0.);
 		cairo_paint (myDrawContext);
-		cairo_dock_set_icon_surface_full (myDrawContext, myData.pBackgroundSurface, 1., 1., myIcon, myContainer);
 	}
 	
 	double dx, dy, fScale;
 	if (myData.pOldSurface != NULL && 1-f > .01)
 	{
-		dx = (iWidth - myData.iOldTextWidth)/2;
-		dy = (iHeight - myData.iOldTextHeight)/2;
-		if (dy < 0)  // peut arriver si une police de la taille de l'icone n'existe pas.
+		fScale = (double)iWidth / myData.iOldTextWidth;  // scale to fill the icon horizontally
+		if (fScale * myData.iOldTextHeight > iHeight)  // if the text is too height, scale down
 		{
-			dy = 0;
-			fScale = (double)iHeight / myData.iOldTextHeight;
-			cairo_save (myDrawContext);
-			cairo_scale (myDrawContext, 1., fScale);  // a priori la difference n'est pas enorme, on laisse donc remplit en largeur.
+			fScale = (double)iHeight / myData.iOldTextHeight;  // that's smaller than the previous value.
 		}
-		else
-			fScale=0;
+		dx = (iWidth - fScale * myData.iOldTextWidth)/2;  // center horizontally
+		dy = iHeight - fScale * myData.iOldTextHeight;  // bottom (we draw the caps/num lock on top).
+		
+		cairo_save (myDrawContext);
+		cairo_translate (myDrawContext, dx, dy);
+		cairo_scale (myDrawContext, fScale, fScale);  // keep ratio
 		cairo_set_source_surface (
 			myDrawContext,
 			myData.pOldSurface,
-			dx,
-			dy);
+			0,
+			0);
 		cairo_paint_with_alpha (myDrawContext, 1-f);
-		if (fScale != 0)
-			cairo_restore (myDrawContext);
+		cairo_restore (myDrawContext);
 	}
+	
 	if (myData.pCurrentSurface != NULL)
 	{
-		dx = (iWidth - myData.iCurrentTextWidth)/2;
-		dy = (iHeight - myData.iCurrentTextHeight)/2;
-		if (dy < 0)
+		fScale = (double)iWidth / myData.iCurrentTextWidth;  // scale to fill the icon horizontally
+		if (fScale * myData.iCurrentTextHeight > iHeight)  // if the text is too height, scale down
 		{
-			dy = 0;
-			fScale = (double)iHeight / myData.iCurrentTextHeight;
-			cairo_save (myDrawContext);
-			cairo_scale (myDrawContext, 1., fScale);
+			fScale = (double)iHeight / myData.iCurrentTextHeight;  // that's smaller than the previous value.
 		}
-		else
-			fScale=0;
+		dx = (iWidth - fScale * myData.iCurrentTextWidth)/2;  // center horizontally
+		dy = iHeight - fScale * myData.iCurrentTextHeight;  // bottom (we draw the caps/num lock on top).
+		
+		cairo_save (myDrawContext);
+		cairo_translate (myDrawContext, dx, dy);
+		cairo_scale (myDrawContext, fScale, fScale);  // keep ratio
 		cairo_set_source_surface (
 			myDrawContext,
 			myData.pCurrentSurface,
-			dx,
-			dy);
+			0,
+			0);
 		cairo_paint_with_alpha (myDrawContext, f);
-		if (fScale != 0)
-			cairo_restore (myDrawContext);
+		cairo_restore (myDrawContext);
 	}
 	
 	CD_APPLET_LEAVE (TRUE);
