@@ -40,33 +40,32 @@ CD_APPLET_DEFINITION (N_("keyboard indicator"),
 
 static void _load_bg_image (void)
 {
-	if (myData.pBackgroundSurface != NULL)
-	{
-		cairo_surface_destroy (myData.pBackgroundSurface);
-		myData.pBackgroundSurface = NULL;
-	}
-	if (myData.iBackgroundTexture != 0)
-	{
-		_cairo_dock_delete_texture (myData.iBackgroundTexture);
-		myData.iBackgroundTexture = 0;
-	}
-	
-	if (myConfig.cBackgroundImage != NULL)
-	{
-		myData.pBackgroundSurface = CD_APPLET_LOAD_SURFACE_FOR_MY_APPLET (myConfig.cBackgroundImage);
-		if (g_bUseOpenGL)
-			myData.iBackgroundTexture = cairo_dock_create_texture_from_surface (myData.pBackgroundSurface);
-	}
+	int iWidth, iHeight;
+	CD_APPLET_GET_MY_ICON_EXTENT (&iWidth, &iHeight);
+	cairo_dock_unload_image_buffer (&myData.bgImage);
+	cairo_dock_load_image_buffer (&myData.bgImage,
+		myConfig.cBackgroundImage,
+		iWidth,
+		iHeight,
+		0);
 }
 
 //\___________ Here is where you initiate your applet. myConfig is already set at this point, and also myIcon, myContainer, myDock, myDesklet (and myDrawContext if you're in dock mode). The macro CD_APPLET_MY_CONF_FILE and CD_APPLET_MY_KEY_FILE can give you access to the applet's conf-file and its corresponding key-file (also available during reload). If you're in desklet mode, myDrawContext is still NULL, and myIcon's buffers has not been filled, because you may not need them then (idem when reloading).
+static gboolean _init (gpointer data)
+{
+	cd_debug ("INIT XKBD");
+	g_return_val_if_fail (myApplet != NULL, FALSE);
+	Window Xid = cairo_dock_get_current_active_window ();
+	cd_xkbd_keyboard_state_changed (myApplet, &Xid);
+	return FALSE;
+}
 CD_APPLET_INIT_BEGIN
 	if (myDesklet)
 	{
 		CD_APPLET_SET_DESKLET_RENDERER ("Simple");  // set a desklet renderer.
 	}
 	
-	myConfig.textDescription.iSize = (int) myIcon->fHeight * myConfig.fTextRatio;
+	myConfig.textDescription.iSize = (int) myIcon->iImageHeight * myConfig.fTextRatio;
 	
 	CD_APPLET_REGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
@@ -77,24 +76,22 @@ CD_APPLET_INIT_BEGIN
 		CAIRO_DOCK_RUN_AFTER,
 		myApplet);
 	
+	// shortkey
+	myData.pKeyBinding = CD_APPLET_BIND_KEY (myConfig.cShortkey,
+		D_("Switch keyboard language"),
+		"Configuration", "shortkey",
+		(CDBindkeyHandler) cd_xkbd_on_keybinding_pull);
+	
 	_load_bg_image ();
 	
 	myData.iCurrentGroup = -1;  // pour forcer le redessin.
 	
-	/*Display *dsp = (Display*)cairo_dock_get_Xdisplay (); // const
-	XklEngine *pEngine = xkl_engine_get_instance (dsp);
-	xkl_engine_start_listen (pEngine, XKLL_MANAGE_WINDOW_STATES | XKLL_MANAGE_LAYOUTS);*/
-	
-	Window Xid = cairo_dock_get_current_active_window ();
-	cd_xkbd_keyboard_state_changed (myApplet, &Xid);
+	g_timeout_add_seconds (1, _init, NULL);
 CD_APPLET_INIT_END
 
 
 //\___________ Here is where you stop your applet. myConfig and myData are still valid, but will be reseted to 0 at the end of the function. In the end, your applet will go back to its original state, as if it had never been activated.
 CD_APPLET_STOP_BEGIN
-	/*Display *dsp = (Display*)cairo_dock_get_Xdisplay (); // const
-	XklEngine *pEngine = xkl_engine_get_instance (dsp);
-	xkl_engine_stop_listen (pEngine, XKLL_MANAGE_WINDOW_STATES | XKLL_MANAGE_LAYOUTS);*/
 	CD_APPLET_UNREGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
 	CD_APPLET_UNREGISTER_FOR_SCROLL_EVENT;
@@ -103,12 +100,14 @@ CD_APPLET_STOP_BEGIN
 		(CairoDockNotificationFunc) cd_xkbd_keyboard_state_changed,
 		myApplet);
 	CD_APPLET_REMOVE_TRANSITION_ON_MY_ICON;
+	
+	cd_keybinder_unbind (myData.pKeyBinding);
 CD_APPLET_STOP_END
 
 
 //\___________ The reload occurs in 2 occasions : when the user changes the applet's config, and when the user reload the cairo-dock's config or modify the desklet's size. The macro CD_APPLET_MY_CONFIG_CHANGED can tell you this. myConfig has already been reloaded at this point if you're in the first case, myData is untouched. You also have the macro CD_APPLET_MY_CONTAINER_TYPE_CHANGED that can tell you if you switched from dock/desklet to desklet/dock mode.
 CD_APPLET_RELOAD_BEGIN
-	myConfig.textDescription.iSize = (int) myIcon->fHeight * myConfig.fTextRatio;
+	myConfig.textDescription.iSize = (int) myIcon->iImageHeight * myConfig.fTextRatio;
 	
 	if (CD_APPLET_MY_CONFIG_CHANGED)
 	{
@@ -121,10 +120,29 @@ CD_APPLET_RELOAD_BEGIN
 		_load_bg_image ();
 		
 		myData.iCurrentGroup = -1;  // pour forcer le redessin.
+
+		// emblems
+		gboolean bCustomEmblems = (myConfig.cEmblemCapsLock || myConfig.cEmblemNumLock); // has emblem
+		if (myData.cEmblemCapsLock || myData.cEmblemNumLock)
+		{	// maybe we need to search for new icons
+			g_free (myData.cEmblemCapsLock);
+			g_free (myData.cEmblemNumLock);
+			myData.cEmblemCapsLock = NULL;
+			myData.cEmblemNumLock = NULL;
+			bCustomEmblems = TRUE; // had emblem
+		}
+		if (!myConfig.bShowKbdIndicator || bCustomEmblems)  // no more indicators or emblems need to be reloaded
+		{
+			CD_APPLET_REMOVE_OVERLAY_ON_MY_ICON (CAIRO_OVERLAY_UPPER_RIGHT);
+			CD_APPLET_REMOVE_OVERLAY_ON_MY_ICON (CAIRO_OVERLAY_UPPER_LEFT);
+			myData.iPreviousIndic = 0;
+		}
 		
 		//\_____________ On declenche le redessin de l'icone.
 		Window Xid = cairo_dock_get_current_active_window ();
 		cd_xkbd_keyboard_state_changed (myApplet, &Xid);
+		
+		cd_keybinder_rebind (myData.pKeyBinding, myConfig.cShortkey, NULL);
 	}
 	else
 	{
