@@ -93,7 +93,7 @@ static void _get_mail_accounts (GKeyFile *pKeyFile, CairoDockModuleInstance *myA
 	for (i = 3; i < length; i ++)  // Icon, Desklet, Configuration + mail groups
 	{
 		cMailAccountName = pGroupList[i];
-		cd_debug ("+ on recupere le compte '%s'\n", cMailAccountName);
+		cd_debug ("+ on recupere le compte '%s'", cMailAccountName);
 		
 		// Get the type of the account.
 		if (! g_key_file_has_key (pKeyFile, cMailAccountName, "type", NULL))
@@ -105,7 +105,7 @@ static void _get_mail_accounts (GKeyFile *pKeyFile, CairoDockModuleInstance *myA
 		
 		for( j = 0; j < MAIL_NB_STORAGE_TYPES; j++ )
 		{
-			if (g_strcasecmp(storage_tab[j].name, cMailAccountType) == 0)
+			if (g_ascii_strcasecmp (storage_tab[j].name, cMailAccountType) == 0)
 			{
 				break;
 			}
@@ -115,7 +115,7 @@ static void _get_mail_accounts (GKeyFile *pKeyFile, CairoDockModuleInstance *myA
 		// in case the account type is unknown, just ignore.
 		if( j >= MAIL_NB_STORAGE_TYPES )
 			continue;
-		cd_debug ("  mail type : %d\n", j);
+		cd_debug ("  mail type : %d", j);
 		
 		// create a new mail account.
 		pMailAccount = g_new0 (CDMailAccount, 1);
@@ -141,7 +141,7 @@ static void _get_mail_accounts (GKeyFile *pKeyFile, CairoDockModuleInstance *myA
 	if (path != NULL) { \
 		_found_image = cairo_dock_search_image_s_path (path); \
 		if (_found_image == NULL)\
-			_found_image = cairo_dock_search_icon_s_path (path); }\
+			_found_image = cairo_dock_search_icon_s_path (path, MAX (myIcon->iImageWidth, myIcon->iImageHeight)); }\
 	_found_image; })
 CD_APPLET_GET_CONFIG_BEGIN
 	//\_________________ On recupere toutes les valeurs de notre fichier de conf.
@@ -347,14 +347,14 @@ static void _cd_mail_remove_account (GtkButton *pButton, CairoDockModuleInstance
 	g_strfreev (pGroupList);
 }
 
-void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pKeyFile)
+void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pKeyFile, GSList *pWidgetList)
 {
 	cd_debug ("");
 	//\____________ On recupere notre widget personnalise (un simple container vide qu'on va remplir avec nos trucs).
-	CairoDockGroupKeyWidget *pGroupKeyWidget = CD_APPLET_GET_CONFIG_PANEL_GROUP_KEY_WIDGET ("Configuration", "add account");
+	CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_gui_find_group_key_widget_in_list (pWidgetList, "Configuration", "add account");
 	g_return_if_fail (pGroupKeyWidget != NULL);
-	
-	GtkWidget *pCustomWidgetBox = gtk_hbox_new (FALSE, 3);
+
+	GtkWidget *pCustomWidgetBox = _gtk_hbox_new (3);
 	gtk_box_pack_end (GTK_BOX (pGroupKeyWidget->pKeyBox),
 		pCustomWidgetBox,
 		FALSE,
@@ -362,14 +362,22 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 		0);
 	
 	//\____________ On cree un combo pour selectionner le type de compte mail qu'on voudrait ajouter
+	#if (GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24)
 	GtkWidget *pMailTypesCombo = gtk_combo_box_new_text();
+	#else
+	GtkWidget *pMailTypesCombo = gtk_combo_box_text_new ();
+	#endif
+	
 	if( pMailTypesCombo )
 	{
 		guint j;
 		for( j = 0; j < MAIL_NB_STORAGE_TYPES; j++ )
 		{
-			gtk_combo_box_append_text( GTK_COMBO_BOX (pMailTypesCombo), storage_tab[j].description );
-			//gtk_widget_set_tooltip_text (pMenuItem, D_("description du type de compte"));
+			#if (GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24)
+			gtk_combo_box_append_text ( GTK_COMBO_BOX (pMailTypesCombo), storage_tab[j].description );
+			#else
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (pMailTypesCombo), storage_tab[j].description );
+			#endif
 		}
 	}
 	gtk_box_pack_start (GTK_BOX (pCustomWidgetBox),
@@ -420,7 +428,7 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 		//pMailAccount = g_ptr_array_index (myData.pMailAccounts, i);  // i-3
 		//cMailAccountName = pMailAccount->name;
 		cMailAccountName = pGroupList[i];
-		cd_debug ("- on ajoute le bouton remove au compte '%s'\n", cMailAccountName);
+		cd_debug ("- on ajoute le bouton remove au compte '%s'", cMailAccountName);
 		if (! g_key_file_has_group (pKeyFile, cMailAccountName))
 		{
 			cd_warning ("mail : no group for mail account '%s'", cMailAccountName);
@@ -428,7 +436,7 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 		}
 		
 		//\____________ On recupere notre widget personnalise (un simple container vide qu'on va remplir avec nos trucs).
-		CairoDockGroupKeyWidget *pGroupKeyWidget = CD_APPLET_GET_CONFIG_PANEL_GROUP_KEY_WIDGET (cMailAccountName, "remove account");
+		CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_gui_find_group_key_widget_in_list (pWidgetList, cMailAccountName, "remove account");
 		if( pGroupKeyWidget == NULL )
 		{
 			cd_warning ("mail : oups, there is a problem in the conf file");
@@ -452,8 +460,8 @@ void cd_mail_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pK
 }
 
 
-void cd_mail_save_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile *pKeyFile)
+void cd_mail_save_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile *pKeyFile, GSList *pWidgetList)
 {
-	cd_debug ("%s (%s)\n", __func__, myIcon->cName);
+	cd_debug ("%s (%s)", __func__, myIcon->cName);
 	// ca c'est si on avait des valeurs a recuperer dans nos widgets personnalises, et a stocker dans le pKeyFile. mais ici ils sont simple, et donc tous pris en charge par le dock.
 }
