@@ -91,6 +91,8 @@ gboolean cd_opengl_load_3D_theme (CairoDockModuleInstance *myApplet, gchar *cThe
 		g_return_val_if_fail (cThemePath && *cThemePath == '/', FALSE);
 		gchar *cCommand = g_strdup_printf ("rm -rf '%s'", cThemePath);
 		int r = system (cCommand);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", cCommand);
 		g_free (cCommand);
 		
 		// on recupere le theme distant.
@@ -417,7 +419,7 @@ void cd_opengl_reset_opengl_datas (CairoDockModuleInstance *myApplet)
 
 void cd_opengl_scene (CairoDockModuleInstance *myApplet, int iWidth, int iHeight)
 {
-	//cd_debug ("%s (%d)\n", __func__, myData.iCoverTransition);
+	//cd_debug ("%s (%d)", __func__, myData.iCoverTransition);
 	_cairo_dock_enable_texture ();
 	_cairo_dock_set_blend_source ();
 	
@@ -512,12 +514,12 @@ void cd_opengl_scene (CairoDockModuleInstance *myApplet, int iWidth, int iHeight
 			if (myData.iPlayingStatus == PLAYER_PLAYING)
 			{
 				_draw_osd (myData.TextureOsdPause, myData.osdPausecoordX, myData.osdPausecoordY, myData.osdPausesizeX, myData.osdPausesizeY);
-				//cd_debug ("%.1f;%.1f ; %.1f;%.1f ;%.1f;%.1f ;%.1f;%.1f\n", u1, v1, u2, v2,u3,v3,u4,v4);
+				//cd_debug ("%.1f;%.1f ; %.1f;%.1f ;%.1f;%.1f ;%.1f;%.1f", u1, v1, u2, v2,u3,v3,u4,v4);
 			}
 			else
 			{
 				_draw_osd (myData.TextureOsdPlay, myData.osdPlaycoordX, myData.osdPlaycoordY, myData.osdPlaysizeX, myData.osdPlaysizeY);
-				//cd_debug ("%.1f;%.1f ; %.1f;%.1f ;%.1f;%.1f ;%.1f;%.1f\n", u1, v1, u2, v2,u3,v3,u4,v4);
+				//cd_debug ("%.1f;%.1f ; %.1f;%.1f ;%.1f;%.1f ;%.1f;%.1f", u1, v1, u2, v2,u3,v3,u4,v4);
 			}
 		}
 		else if (myData.mouseOnButton2)
@@ -534,11 +536,7 @@ void cd_opengl_scene (CairoDockModuleInstance *myApplet, int iWidth, int iHeight
 		}
 		else if (myData.iPlayingStatus != PLAYER_PLAYING)
 		{
-			if (myData.bIsRunning)  // on verifie que le lecteur est bien ouvert (il se peut qu'il ne nous previenne pas lorsqu'il quitte).
-			{
-				cd_musicplayer_dbus_detect_player ();
-			}
-			if (myData.bIsRunning)  // si rhythmbox n'est pas lancé, on n'affiche pas l'osd de pause ;-)
+			if (myData.bIsRunning)  // si rhythmbox n'est pas lance, on n'affiche pas l'osd de pause ;-)
 			{
 				_draw_osd (myData.TextureOsdPause, myData.osdPausecoordX, myData.osdPausecoordY, myData.osdPausesizeX, myData.osdPausesizeY);
 			}
