@@ -22,8 +22,6 @@
 #include "applet-struct.h"
 #include "applet-menu.h"
 
-static GList *s_pItemList = NULL;
-
 static void _on_activate_item (GtkWidget *pMenuItem, CDQuickBrowserItem *pItem);
 
 static int _sort_item (CDQuickBrowserItem *pItem1, CDQuickBrowserItem *pItem2)
@@ -115,16 +113,30 @@ static void _init_fill_menu_from_dir (CDQuickBrowserItem *pItem)
 	gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
 	g_signal_connect (G_OBJECT (pMenuItem), "activate", G_CALLBACK(_on_activate_item), pOpenDirItem);
 }
+
+
+static void _drag_data_get (GtkWidget *pWidget, GdkDragContext *pDragContext,
+	GtkSelectionData *pSelectionData, guint iInfo, guint iTime, CDQuickBrowserItem *pItem)
+{
+	gchar *cURI = g_filename_to_uri (pItem->cPath, NULL, NULL);
+	if (cURI != NULL)
+	{
+		gtk_selection_data_set (pSelectionData, gtk_selection_data_get_target (pSelectionData), 8, (guchar *) cURI, strlen (cURI));
+		g_free (cURI);
+	}
+}
+
 static void _fill_submenu_with_items (CDQuickBrowserItem *pRootItem, int iNbSubItemsAtOnce)
 {
 	CairoDockModuleInstance *myApplet = pRootItem->pApplet;
 	GtkWidget *pMenu = pRootItem->pSubMenu;
 	GList *pFirstItem = pRootItem->pCurrentItem;
-	
+
+	// static GtkTargetEntry s_pMenuItemTargets[] = { {(gchar*) "text/uri-list", 0, 0} }; // for drag and drop support
+
 	CDQuickBrowserItem *pItem;
 	gchar *cFileName;
 	GtkWidget *pMenuItem;
-	gboolean bSetImage;
 	gchar *cName = NULL, *cURI = NULL, *cIconName = NULL;
 	gboolean bIsDirectory;
 	int iVolumeID;
@@ -136,7 +148,6 @@ static void _fill_submenu_with_items (CDQuickBrowserItem *pRootItem, int iNbSubI
 		pItem = l->data;
 		
 		//\______________ On cree l'entree avec son icone si necessaire.
-		bSetImage = FALSE;
 		if (myConfig.bHasIcons)
 		{
 			cairo_dock_fm_get_file_info (pItem->cPath, &cName, &cURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, 0);
@@ -145,6 +156,7 @@ static void _fill_submenu_with_items (CDQuickBrowserItem *pRootItem, int iNbSubI
 			g_free (cURI);
 			cURI = NULL;
 		}
+
 		cFileName = strrchr (pItem->cPath, '/');
 		if (cFileName)
 			cFileName ++;
@@ -156,10 +168,7 @@ static void _fill_submenu_with_items (CDQuickBrowserItem *pRootItem, int iNbSubI
 			g_free (cPath);
 			GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
 			g_object_unref (pixbuf);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-			gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (pMenuItem), TRUE);
-#endif
-			gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
+			_gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
 			g_free (cIconName);
 			cIconName = NULL;
 		}
@@ -167,7 +176,7 @@ static void _fill_submenu_with_items (CDQuickBrowserItem *pRootItem, int iNbSubI
 		{
 			pMenuItem = gtk_menu_item_new_with_label (cFileName);
 		}
-		
+
 		//\______________ On l'insere dans le menu.
 		gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
 		g_signal_connect (G_OBJECT (pMenuItem), "activate", G_CALLBACK(_on_activate_item), pItem);
@@ -176,6 +185,24 @@ static void _fill_submenu_with_items (CDQuickBrowserItem *pRootItem, int iNbSubI
 		{
 			gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pItem->pSubMenu);
 		}
+		else
+		{
+			//\______________ Add drag and drop support for files only
+			gtk_drag_source_set (pMenuItem, GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
+				NULL, 0,
+				GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_LINK | GDK_ACTION_ASK);
+			
+			gtk_drag_source_add_text_targets (pMenuItem);
+			gtk_drag_source_add_uri_targets (pMenuItem);
+			
+			// add an icon: the current pixbuf (add it now, once and for all).
+			if (GTK_IS_IMAGE_MENU_ITEM (pMenuItem)) // some items don't have any icon.
+			{
+				gtk_drag_source_set_icon_pixbuf (pMenuItem,
+					gtk_image_get_pixbuf (GTK_IMAGE (gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (pMenuItem)))));  // GTK+ retains a reference on the pixbuf; when pMenuItem disappear, it will naturally loose this reference.
+			}
+			g_signal_connect (pMenuItem, "drag-data-get", G_CALLBACK (_drag_data_get), pItem);
+		}
 	}
 	pRootItem->pCurrentItem = l;
 }
