@@ -28,62 +28,40 @@
 #include "applet-load-icons.h"
 #include "applet-drives.h"
 
+#define CD_SHORTCUT_DEFAULT_DRIVE_ICON_FILENAME "drive-harddisk"
 
-static void _load_disk_icon (Icon *pIcon)
+
+void cd_shortcuts_add_progress_bar (Icon *pIcon, CairoDockModuleInstance *myApplet)
 {
-	CairoDockModuleInstance *myApplet = pIcon->pLinkedApplet;
-	int iWidth = pIcon->iImageWidth;
-	int iHeight = pIcon->iImageHeight;
-	if (pIcon->cFileName)  // icone possedant une image, on affiche celle-ci.
+	// set a progress bar to display the disk space
+	CairoProgressBarAttribute attr;
+	memset (&attr, 0, sizeof (CairoProgressBarAttribute));
+	if (myConfig.iDisplayType == CD_SHOW_USED_SPACE || myConfig.iDisplayType == CD_SHOW_USED_SPACE_PERCENT)
 	{
-		gchar *cIconPath = cairo_dock_search_icon_s_path (pIcon->cFileName);
-		if (cIconPath != NULL && *cIconPath != '\0')
-		{
-			pIcon->pIconBuffer = cairo_dock_create_surface_from_image_simple (cIconPath,
-				iWidth,
-				iHeight);
-			if (pIcon->pIconBuffer != NULL && myConfig.bDrawBar)
-			{
-				CDDiskUsage *pDiskUsage = CD_APPLET_GET_MY_ICON_DATA (pIcon);
-				if (pDiskUsage != NULL && pDiskUsage->iTotal != 0)
-				{
-					double fValue;
-					switch (myConfig.iDisplayType)
-					{
-						case CD_SHOW_FREE_SPACE :
-							fValue = (double) pDiskUsage->iAvail / pDiskUsage->iTotal;
-						break ;
-						case CD_SHOW_USED_SPACE :
-							fValue = (double) - pDiskUsage->iUsed / pDiskUsage->iTotal;  // <0 => du vert au rouge.
-						break ;
-						case CD_SHOW_FREE_SPACE_PERCENT :
-							fValue = (double) pDiskUsage->iAvail / pDiskUsage->iTotal;
-						break ;
-						case CD_SHOW_USED_SPACE_PERCENT :
-							fValue = (double) - pDiskUsage->iUsed / pDiskUsage->iTotal;  // <0 => du vert au rouge.
-						break ;
-						default:
-							fValue = 0.;
-						break;
-					}
-					cairo_t *pCairoContext = cairo_create (pIcon->pIconBuffer);
-					cairo_dock_draw_bar_on_icon (pCairoContext, fValue, pIcon);
-					cairo_destroy (pCairoContext);
-				}
-			}
-		}
-		g_free (cIconPath);
+		attr.bInverted = TRUE;
 	}
+	CairoDataRendererAttribute *pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
+	pRenderAttr->cModelName = "progressbar";
+	cairo_dock_add_new_data_renderer_on_icon (pIcon, pIcon->pContainer, pRenderAttr);
 }
 
-static void _init_disk_usage (Icon *pIcon, CairoDockModuleInstance *myApplet)
+
+void _init_disk_usage (Icon *pIcon, CairoDockModuleInstance *myApplet)
 {
-	pIcon->iface.load_image = _load_disk_icon;
-	pIcon->pLinkedApplet = myApplet;
-	CDDiskUsage *pDiskUsage = g_new0 (CDDiskUsage, 1);
-	CD_APPLET_SET_MY_ICON_DATA (pIcon, pDiskUsage);
+	// ensure the applet has a valid icon, in case the VFS didn't give us one.
+	if (pIcon->cFileName == NULL)
+		pIcon->cFileName = cairo_dock_search_icon_s_path (CD_SHORTCUT_DEFAULT_DRIVE_ICON_FILENAME, CAIRO_DOCK_DEFAULT_ICON_SIZE);
+		
 	if (pIcon->cCommand)
+	{
+		// set our private data for disk usage
+		CDDiskUsage *pDiskUsage = g_new0 (CDDiskUsage, 1);
+		pDiskUsage->iPrevAvail = -1;  // data not yet retrieved (0 bytes is a valid value for non writable disks).
+		CD_APPLET_SET_MY_ICON_DATA (pIcon, pDiskUsage);
+		
+		// get the current disk usage
 		cd_shortcuts_get_fs_stat (pIcon->cCommand, pDiskUsage);
+	}
 }
 
 static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar *cBaseURI, GList *pIconsList, CairoContainer *pContainer, CairoDockModuleInstance *myApplet)
@@ -129,15 +107,20 @@ static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar
 				cd_warning ("couldn't create an icon for this mount point");
 				return ;
 			}
-			pNewIcon->iType = CD_DRIVE_GROUP;
-			_init_disk_usage (pNewIcon, myApplet);
+			pNewIcon->iGroup = CD_DRIVE_GROUP;
 			
 			//\_______________________ on la place au bon endroit suivant son nom.
 			cd_shortcuts_set_icon_order_by_name (pNewIcon, pIconsList);
-			//g_print (" new drive : %s, order = %.2f\n", pNewIcon->cName, pNewIcon->fOrder);
+			cd_debug (" new drive : %s, %s", pNewIcon->cName, pNewIcon->cCommand);
 			
 			//\_______________________ on l'insere dans la liste.
 			CD_APPLET_ADD_ICON_IN_MY_ICONS_LIST (pNewIcon);
+			_init_disk_usage (pNewIcon, myApplet);
+			if (pNewIcon->cCommand)
+			{
+				cd_shortcuts_add_progress_bar (pNewIcon, myApplet);
+				cd_shortcuts_display_disk_usage (pNewIcon, myApplet);
+			}
 			
 			//\_______________________ on affiche un message.
 			gboolean bIsMounted = FALSE;
@@ -165,7 +148,7 @@ static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar
 				cd_warning ("  an unknown mount point was modified");
 				return ;
 			}
-			//g_print (" %s is modified\n", pConcernedIcon->cName);
+			cd_debug (" %s is modified (%s)", pConcernedIcon->cName, pConcernedIcon->cCommand);
 			
 			//\_______________________ on recupere les infos actuelles.
 			Icon *pNewIcon = cairo_dock_fm_create_icon_from_URI (cURI, pContainer, CAIRO_DOCK_FM_SORT_BY_NAME);
@@ -174,7 +157,7 @@ static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar
 				cd_warning ("couldn't create an icon for this mount point");
 				return ;
 			}
-			pNewIcon->iType = CD_DRIVE_GROUP;
+			pNewIcon->iGroup = CD_DRIVE_GROUP;
 			
 			//\_______________________ on remplace l'icone si des choses ont change.
 			if (cairo_dock_strings_differ (pConcernedIcon->cName, pNewIcon->cName) || cairo_dock_strings_differ (pConcernedIcon->cFileName, pNewIcon->cFileName))
@@ -184,8 +167,12 @@ static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar
 				CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (pConcernedIcon);
 				
 				cd_shortcuts_set_icon_order_by_name (pNewIcon, pIconsList);
-				_init_disk_usage (pNewIcon, myApplet);
 				CD_APPLET_ADD_ICON_IN_MY_ICONS_LIST (pNewIcon);
+				_init_disk_usage (pNewIcon, myApplet);
+				if (pNewIcon->cCommand)
+				{
+					cd_shortcuts_add_progress_bar (pNewIcon, myApplet);
+				}
 				
 				pConcernedIcon = pNewIcon;  // pConcernedIcon a ete detruite, on pointe sur la nouvelle pour pouvoir afficher un dialogue juste apres.
 			}
@@ -195,6 +182,8 @@ static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar
 				pNewIcon = NULL;
 			}
 			
+			cd_shortcuts_display_disk_usage (pConcernedIcon, myApplet);
+			
 			//\_______________________ on affiche un message.
 			cairo_dock_remove_dialog_if_any (pConcernedIcon);  // on empeche la multiplication des dialogues de (de)montage.
 			gboolean bIsMounted = FALSE;
@@ -221,11 +210,13 @@ static void _manage_event_on_drive (CairoDockFMEventType iEventType, const gchar
 			}
 		}
 		break ;
+		case CAIRO_DOCK_NB_EVENT_ON_FILES :
+		break ;
 	}
 	g_free (cURI);
 }
 
-static void _cd_shortcuts_on_drive_event (CairoDockFMEventType iEventType, const gchar *cURI, CairoDockModuleInstance *myApplet)
+void cd_shortcuts_on_drive_event (CairoDockFMEventType iEventType, const gchar *cURI, CairoDockModuleInstance *myApplet)
 {
 	g_return_if_fail (cURI != NULL);
 	CD_APPLET_ENTER;
@@ -257,12 +248,12 @@ static void _cd_shortcuts_on_drive_event (CairoDockFMEventType iEventType, const
 		for (ic = pIconsList; ic != NULL; ic = ic->next)
 		{
 			icon = ic->data;
-			if (icon->iType == CD_BOOKMARK_GROUP)
+			if (icon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)
 			{
 				if (strncmp (cTargetURI, icon->cBaseURI, strlen (cTargetURI)) == 0)
 				{
 					//g_print ("le signet '%s' est situe sur un point de montage ayant change (%s)\n", icon->cBaseURI, cTargetURI);
-					gchar *cName = NULL, *cRealURI = NULL, *cIconName = NULL, *cUserName = NULL;
+					gchar *cName = NULL, *cRealURI = NULL, *cIconName = NULL;
 					int iVolumeID = 0;
 					gboolean bIsDirectory = FALSE;
 					double fOrder;
@@ -293,7 +284,7 @@ static void _cd_shortcuts_on_drive_event (CairoDockFMEventType iEventType, const
 }
 
 
-GList * cd_shortcuts_list_drives (CairoDockModuleInstance *myApplet)
+GList * cd_shortcuts_list_drives (CDSharedMemory *pSharedMemory)
 {
 	GList *pIconList = NULL;
 	gchar *cFullURI = NULL;
@@ -305,10 +296,9 @@ GList * cd_shortcuts_list_drives (CairoDockModuleInstance *myApplet)
 	{
 		cd_warning ("couldn't detect any drives");  // on decide de poursuivre malgre tout, pour les signets.
 	}
+	/// TODO: if ! bListBookmarks, then we should add the Home in the drives list, to have the disk space information...
 	
-	if (! cairo_dock_fm_add_monitor_full (cFullURI, TRUE, NULL, (CairoDockFMMonitorCallback) _cd_shortcuts_on_drive_event, myApplet))
-		cd_warning ("Shortcuts : can't monitor drives");
-	myData.cDisksURI = cFullURI;
+	pSharedMemory->cDisksURI = cFullURI;
 	
 	//\_______________________ On initialise les usages disque.
 	Icon *pIcon;
@@ -316,7 +306,7 @@ GList * cd_shortcuts_list_drives (CairoDockModuleInstance *myApplet)
 	for (ic = pIconList; ic != NULL; ic = ic->next)
 	{
 		pIcon = ic->data;
-		_init_disk_usage (pIcon, myApplet);
+		_init_disk_usage (pIcon, pSharedMemory->pApplet);
 	}
 	
 	return pIconList;
