@@ -40,7 +40,7 @@ CD_APPLET_DEFINE_BEGIN (N_("stack"),
 	cairo_dock_register_notification_on_object (&myContainersMgr,
 		NOTIFICATION_DROP_DATA,
 		(CairoDockNotificationFunc) cd_stack_on_drop_data,
-		CAIRO_DOCK_RUN_FIRST, NULL);
+		CAIRO_DOCK_RUN_FIRST, NULL);  // future instances of the applet will register before this, and therefore handle the drop of files on themselves.
 CD_APPLET_DEFINE_END
 
 
@@ -61,9 +61,7 @@ CD_APPLET_INIT_END
 
 //\___________ Here is where you stop your applet. myConfig and myData are still valid, but will be reseted to 0 at the end of the function. In the end, your applet will go back to its original state, as if it had never been activated.
 CD_APPLET_STOP_BEGIN
-	cairo_dock_remove_notification_func_on_object (&myContainersMgr,
-		NOTIFICATION_CLICK_ICON,
-		(CairoDockNotificationFunc) CD_APPLET_ON_CLICK_FUNC, myApplet);
+	CD_APPLET_UNREGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
 	CD_APPLET_UNREGISTER_FOR_DROP_DATA_EVENT;
 	CD_APPLET_UNREGISTER_FOR_MIDDLE_CLICK_EVENT;
@@ -73,6 +71,8 @@ CD_APPLET_STOP_BEGIN
 		gchar *cCommand = g_strdup_printf ("rm -rf \"%s\"", myConfig.cStackDir);
 		cd_debug ("Stack : %s", myConfig.cStackDir);
 		int r = system (cCommand);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", cCommand);
 		g_free (cCommand);
 	}
 	
